@@ -37,17 +37,19 @@ from typing import (
 from aea.agent import Agent
 from aea.agent_loop import AsyncAgentLoop, BaseAgentLoop, SyncAgentLoop
 from aea.configurations.base import PublicId
-from aea.configurations.constants import DEFAULT_SEARCH_SERVICE_ADDRESS
-from aea.connections.base import Connection
+from aea.configurations.constants import (
+    DEFAULT_BUILD_DIR_NAME,
+    DEFAULT_SEARCH_SERVICE_ADDRESS,
+)
 from aea.context.base import AgentContext
 from aea.crypto.ledger_apis import DEFAULT_CURRENCY_DENOMINATIONS
 from aea.crypto.wallet import Wallet
 from aea.decision_maker.base import DecisionMakerHandler
 from aea.error_handler.base import AbstractErrorHandler
 from aea.error_handler.default import ErrorHandler as DefaultErrorHandler
-from aea.exceptions import AEAException, _StopRuntime
+from aea.exceptions import AEAException, _StopRuntime, enforce
 from aea.helpers.exception_policy import ExceptionPolicyEnum
-from aea.helpers.logging import AgentLoggerAdapter, get_logger
+from aea.helpers.logging import AgentLoggerAdapter, WithLogger, get_logger
 from aea.identity.base import Identity
 from aea.mail.base import Envelope
 from aea.protocols.base import Message, Protocol
@@ -65,13 +67,14 @@ class AEA(Agent):
     }
     DEFAULT_RUN_LOOP: str = "async"
 
-    DEFAULT_BUILD_DIR_NAME = ".build"
+    DEFAULT_BUILD_DIR_NAME = DEFAULT_BUILD_DIR_NAME
 
     def __init__(
         self,
         identity: Identity,
         wallet: Wallet,
         resources: Resources,
+        data_dir: str,
         loop: Optional[AbstractEventLoop] = None,
         period: float = 0.05,
         execution_timeout: float = 0,
@@ -89,7 +92,7 @@ class AEA(Agent):
         connection_ids: Optional[Collection[PublicId]] = None,
         search_service_address: str = DEFAULT_SEARCH_SERVICE_ADDRESS,
         storage_uri: Optional[str] = None,
-        **kwargs,
+        **kwargs: Any,
     ) -> None:
         """
         Instantiate the agent.
@@ -97,6 +100,7 @@ class AEA(Agent):
         :param identity: the identity of the agent
         :param wallet: the wallet of the agent.
         :param resources: the resources (protocols and skills) of the agent.
+        :param data_dir: directory where to put local files.
         :param loop: the event loop to run the connections.
         :param period: period to call agent's act
         :param execution_timeout: amount of time to limit single act/handle to execute.
@@ -123,6 +127,8 @@ class AEA(Agent):
             logger=get_logger(__name__, identity.name), agent_name=identity.name,
         )
 
+        self._resources = resources
+
         super().__init__(
             identity=identity,
             connections=[],
@@ -134,6 +140,35 @@ class AEA(Agent):
             logger=cast(Logger, aea_logger),
         )
 
+        enforce(
+            bool(self.resources.get_all_connections()),
+            "Resource connections list is empty, please add at least one connection!",
+        )
+
+        default_routing = default_routing if default_routing is not None else {}
+        connection_ids = connection_ids or []
+        connections = [
+            c
+            for c in self.resources.get_all_connections()
+            if (not connection_ids) or (c.connection_id in connection_ids)
+        ]
+        enforce(
+            bool(connections),
+            "Please check connection_ids and resources.connections! No connection left after filtering!",
+        )
+
+        self._set_runtime_and_mail_boxes(
+            runtime_class=self._get_runtime_class(),
+            loop_mode=loop_mode,
+            loop=loop,
+            multiplexer_options=dict(
+                connections=connections,
+                default_routing=default_routing,
+                default_connection=default_connection,
+                protocols=self.resources.get_all_protocols(),
+            ),
+        )
+
         self.max_reactions = max_reactions
 
         if decision_maker_handler_class is None:
@@ -170,16 +205,15 @@ class AEA(Agent):
             default_ledger_id,
             currency_denominations,
             default_connection,
-            default_routing if default_routing is not None else {},
+            default_routing,
             search_service_address,
             decision_maker_handler.self_address,
-            storage_callable=lambda: self._runtime.storage,
+            data_dir,
+            storage_callable=lambda: self.runtime.storage,
             build_dir=self.get_build_dir(),
             **kwargs,
         )
         self._execution_timeout = execution_timeout
-        self._connection_ids = connection_ids
-        self._resources = resources
         self._filter = Filter(
             self.resources, self.runtime.decision_maker.message_out_queue
         )
@@ -220,10 +254,7 @@ class AEA(Agent):
         """
         Set up the agent.
 
-        Performs the following:
-
-        - loads the resources (unless in programmatic mode)
-        - calls setup() on the resources
+        Calls setup() on the resources.
 
         :return: None
         """
@@ -233,34 +264,12 @@ class AEA(Agent):
         """
         Perform actions.
 
-        Calls act() of each active behaviour.
+        Adds new handlers and behaviours for use/execution by the runtime.
 
         :return: None
         """
         self.filter.handle_new_handlers_and_behaviours()
 
-    @property
-    def active_connections(self) -> List[Connection]:
-        """Return list of active connections."""
-        connections = self.resources.get_all_connections()
-        if self._connection_ids is not None:
-            connections = [
-                c for c in connections if c.connection_id in self._connection_ids
-            ]
-        return connections
-
-    def get_multiplexer_setup_options(self) -> Optional[Dict]:
-        """
-        Get options to pass to Multiplexer.setup.
-
-        :return: dict of kwargs
-        """
-        return dict(
-            connections=self.active_connections,
-            default_routing=self.context.default_routing,
-            default_connection=self.context.default_connection,
-        )
-
     def _get_error_handler(self) -> Type[AbstractErrorHandler]:
         """Get error handler."""
         return self._error_handler_class
@@ -269,7 +278,9 @@ class AEA(Agent):
         self, envelope: Envelope
     ) -> Tuple[Optional[Message], List[Handler]]:
         """Get the msg and its handlers."""
-        protocol = self.resources.get_protocol(envelope.protocol_id)
+        protocol = self.resources.get_protocol_by_specification_id(
+            envelope.protocol_specification_id
+        )
 
         msg, handlers = self._handle_decoding(envelope, protocol)
 
@@ -310,10 +321,12 @@ class AEA(Agent):
         """
         Handle an envelope.
 
+        Performs the following:
+
         - fetching the protocol referenced by the envelope, and
-        - returning an envelope to sender if the protocol is unsupported, using the error handler, or
-        - returning an envelope to sender if there is a decoding error, using the error handler, or
-        - returning an envelope to sender if no active handler is available for the specified protocol, using the error handler, or
+        - handling if the protocol is unsupported, using the error handler, or
+        - handling if there is a decoding error, using the error handler, or
+        - handling if no active handler is available for the specified protocol, using the error handler, or
         - handling the message recovered from the envelope with all active handlers for the specified protocol.
 
         :param envelope: the envelope to handle.
@@ -328,10 +341,10 @@ class AEA(Agent):
         for handler in handlers:
             handler.handle_wrapper(msg)
 
-    def _setup_loggers(self):
+    def _setup_loggers(self) -> None:
         """Set up logger with agent name."""
         for element in [
-            self.runtime.main_loop,
+            self.runtime.agent_loop,
             self.runtime.multiplexer,
             self.runtime.task_manager,
             self.resources.component_registry,
@@ -339,8 +352,10 @@ class AEA(Agent):
             self.resources.handler_registry,
             self.resources.model_registry,
         ]:
-            element.logger = AgentLoggerAdapter(
-                element.logger, agent_name=self._identity.name
+            element = cast(WithLogger, element)
+            element.logger = cast(
+                Logger,
+                AgentLoggerAdapter(element.logger, agent_name=self._identity.name),
             )
 
     def get_periodic_tasks(
@@ -390,7 +405,7 @@ class AEA(Agent):
         :return: bool, propagate exception if True otherwise skip it.
         """
         # docstyle: ignore # noqa: E800
-        def log_exception(e, fn, is_debug: bool = False):
+        def log_exception(e: Exception, fn: Callable, is_debug: bool = False) -> None:
             if is_debug:
                 self.logger.debug(f"<{e}> raised during `{fn}`")
             else:
