@@ -42,7 +42,7 @@ from aea.crypto.registries import crypto_registry
 )
 @click.pass_context
 @check_aea_project
-def remove_key(click_context, type_, connection):
+def remove_key(click_context: click.Context, type_: str, connection: bool) -> None:
     """Remove a private key from the wallet of the agent."""
     _remove_private_key(click_context, type_, connection)
 
@@ -63,7 +63,7 @@ def _remove_private_key(
     _try_remove_key(ctx, type_, connection)
 
 
-def _try_remove_key(ctx: Context, type_: str, connection: bool = False):
+def _try_remove_key(ctx: Context, type_: str, connection: bool = False) -> None:
     private_keys = (
         ctx.agent_config.connection_private_key_paths
         if connection
