@@ -21,7 +21,6 @@ import asyncio
 import collections
 import datetime
 import logging
-import subprocess  # nosec
 import time
 from abc import ABC, abstractmethod
 from asyncio import CancelledError
@@ -77,7 +76,7 @@ class AsyncState:
 
     def __init__(
         self, initial_state: Any = None, states_enum: Optional[Container[Any]] = None
-    ):
+    ) -> None:
         """Init async state.
 
         :param initial_state: state to set on start.
@@ -143,7 +142,7 @@ class AsyncState:
     def _watcher_result_callback(watcher: Future) -> Callable:
         """Create callback for watcher result."""
         # docstyle.
-        def _callback(result):
+        def _callback(result: Any) -> None:
             if watcher.done():  # pragma: nocover
                 return
             watcher.set_result(result)
@@ -153,7 +152,7 @@ class AsyncState:
     async def wait(self, state_or_states: Union[Any, Sequence[Any]]) -> Tuple[Any, Any]:
         """Wait state to be set.
 
-        :params state_or_states: state or list of states.
+        :param state_or_states: state or list of states.
         :return: tuple of previous state and new state.
         """
         states = ensure_list(state_or_states)
@@ -208,7 +207,7 @@ class PeriodicCaller:
         start_at: Optional[datetime.datetime] = None,
         exception_callback: Optional[Callable[[Callable, Exception], None]] = None,
         loop: Optional[AbstractEventLoop] = None,
-    ):
+    ) -> None:
         """
         Init periodic caller.
 
@@ -312,7 +311,7 @@ class AnotherThreadTask:
 class ThreadedAsyncRunner(Thread):
     """Util to run thread with event loop and execute coroutines inside."""
 
-    def __init__(self, loop=None) -> None:
+    def __init__(self, loop: Optional[AbstractEventLoop] = None) -> None:
         """
         Init threaded runner.
 
@@ -361,45 +360,6 @@ class ThreadedAsyncRunner(Thread):
         _default_logger.debug("Stopped.")
 
 
-class AwaitableProc:
-    """Async-friendly subprocess.Popen."""
-
-    def __init__(self, *args, **kwargs):
-        """Initialise awaitable proc."""
-        self.args = args
-        self.kwargs = kwargs
-        self.proc = None
-        self._thread = None
-        self.loop = None
-        self.future = None
-
-    async def start(self):
-        """Start the subprocess."""
-        self.proc = subprocess.Popen(*self.args, **self.kwargs)  # nosec
-        self.loop = asyncio.get_event_loop()
-        self.future = asyncio.futures.Future()
-        self._thread = Thread(target=self._in_thread)
-        self._thread.start()
-        try:
-            return await asyncio.shield(self.future)
-        except asyncio.CancelledError:  # pragma: nocover
-            self.proc.terminate()
-            return await self.future
-        finally:
-            self._thread.join()
-
-    def _in_thread(self):
-        """Run in dedicated thread."""
-        self.proc.wait()
-        self.loop.call_soon_threadsafe(self._set_return_code, self.proc.returncode)
-
-    def _set_return_code(self, code: int) -> None:
-        """Set future with return code."""
-        if self.future.done():  # pragma: nocover
-            return
-        self.future.set_result(code)
-
-
 class ItemGetter:
     """Virtual queue like object to get items from getters function."""
 
@@ -451,12 +411,12 @@ class HandlerItemGetter(ItemGetter):
         :return: callable to return handler and item from getter.
         """
         # for pydocstyle
-        async def _getter():
+        async def _getter() -> Tuple[Callable, Any]:
             return handler, await getter()
 
         return _getter
 
-    def __init__(self, getters: List[Tuple[Callable[[Any], None], Callable]]):
+    def __init__(self, getters: List[Tuple[Callable[[Any], None], Callable]]) -> None:
         """
         Init HandlerItemGetter.
 
@@ -503,6 +463,7 @@ class Runnable(ABC):
         self._got_result = False
         self._was_cancelled = False
         self._is_running: bool = False
+        self._stop_called = 0
 
     def start(self) -> bool:
         """
@@ -519,6 +480,13 @@ class Runnable(ABC):
         self._set_loop()
         self._completed_event = asyncio.Event(loop=self._loop)
         self._was_cancelled = False
+
+        if self._stop_called > 0:
+            # used in case of race when stop called before start!
+            _default_logger.debug(f"{self} was already stopped before started!")
+            self._stop_called = 0
+            return True
+
         self._set_task()
 
         if self._threaded:
@@ -527,7 +495,7 @@ class Runnable(ABC):
             )
             self._thread.setDaemon(True)
             self._thread.start()
-
+        self._stop_called = 0
         return True
 
     def _thread_target(self) -> None:
@@ -556,6 +524,7 @@ class Runnable(ABC):
         if not self._loop:  # pragma: nocover
             raise ValueError("Loop was not set.")
         self._task = self._loop.create_task(self._run_wrapper())
+        _default_logger.debug(f"{self} task set")
 
     async def _run_wrapper(self) -> None:
         """Wrap run() method."""
@@ -627,15 +596,18 @@ class Runnable(ABC):
                 asyncio.wait_for(self._wait(), timeout=timeout)
             )
 
-    def _wait_async(self, timeout):
+    def _wait_async(self, timeout: Optional[float] = None) -> Awaitable:
         if not self._threaded:
             return asyncio.wait_for(self._wait(), timeout=timeout)
 
+        if self._task is None:  # pragma: nocover
+            raise ValueError("task is not set!")
+
         # for threaded mode create a future and bind it to task
         loop = asyncio.get_event_loop()
         fut = loop.create_future()
 
-        def done(task):
+        def done(task: Future) -> None:
             try:
                 if fut.done():  # pragma: nocover
                     return
@@ -671,6 +643,7 @@ class Runnable(ABC):
         """Stop runnable."""
         _default_logger.debug(f"{self} is going to be stopped {self._task}")
         if not self._task or not self._loop:  # pragma: nocover
+            self._stop_called += 1
             return
 
         if self._task.done():
@@ -689,7 +662,7 @@ class Runnable(ABC):
         self._was_cancelled = True
         self._task.cancel()
 
-    def start_and_wait_completed(self, *args, **kwargs) -> Awaitable:
+    def start_and_wait_completed(self, *args: Any, **kwargs: Any) -> Awaitable:
         """Alias for start and wait methods."""
         self.start()
         return self.wait_completed(*args, **kwargs)
