@@ -16,6 +16,7 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
+
 """
 This module contains the classes required for dialogue management.
 
@@ -24,13 +25,13 @@ This module contains the classes required for dialogue management.
 - Dialogues: The dialogues class keeps track of all dialogues.
 """
 import inspect
-import itertools
 import secrets
 import sys
 from collections import defaultdict, namedtuple
 from enum import Enum
 from inspect import signature
 from typing import (
+    Any,
     Callable,
     Dict,
     FrozenSet,
@@ -128,7 +129,7 @@ class DialogueLabel:
         """Get the address of the dialogue starter."""
         return self._dialogue_starter_addr
 
-    def __eq__(self, other) -> bool:
+    def __eq__(self, other: Any) -> bool:
         """Check for equality between two DialogueLabel objects."""
         if isinstance(other, DialogueLabel):
             return (
@@ -180,7 +181,7 @@ class DialogueLabel:
         )
         return dialogue_label
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Get the string representation."""
         return "{}_{}_{}_{}".format(
             self.dialogue_starter_reference,
@@ -214,7 +215,7 @@ class _DialogueMeta(type):
     Creates classlevvel Rules instance
     """
 
-    def __new__(cls, name: str, bases: Tuple[Type], dct: Dict):
+    def __new__(cls, name: str, bases: Tuple[Type], dct: Dict) -> "_DialogueMeta":
         """Construct a new type."""
         # set class level `_rules`
         dialogue_cls: Type[Dialogue] = super().__new__(cls, name, bases, dct)
@@ -309,14 +310,14 @@ class Dialogue(metaclass=_DialogueMeta):
     class Role(Enum):
         """This class defines the agent's role in a dialogue."""
 
-        def __str__(self):
+        def __str__(self) -> str:
             """Get the string representation."""
             return str(self.value)
 
     class EndState(Enum):
         """This class defines the end states of a dialogue."""
 
-        def __str__(self):
+        def __str__(self) -> str:
             """Get the string representation."""
             return str(self.value)
 
@@ -351,6 +352,8 @@ class Dialogue(metaclass=_DialogueMeta):
         )
         self._message_class = message_class
         self._terminal_state_callbacks: Set[Callable[["Dialogue"], None]] = set()
+        self._last_message_id: Optional[int] = None
+        self._ordered_message_ids: List[int] = []
 
     def add_terminal_state_callback(self, fn: Callable[["Dialogue"], None]) -> None:
         """
@@ -361,7 +364,7 @@ class Dialogue(metaclass=_DialogueMeta):
         """
         self._terminal_state_callbacks.add(fn)
 
-    def __eq__(self, other) -> bool:
+    def __eq__(self, other: Any) -> bool:
         """Compare two dialogues."""
         return (
             type(self) == type(other)  # pylint: disable=unidiomatic-typecheck
@@ -369,6 +372,7 @@ class Dialogue(metaclass=_DialogueMeta):
             and self.message_class == other.message_class
             and self._incoming_messages == other._incoming_messages
             and self._outgoing_messages == other._outgoing_messages
+            and self._ordered_message_ids == other._ordered_message_ids
             and self.role == other.role
             and self.self_address == other.self_address
         )
@@ -381,6 +385,8 @@ class Dialogue(metaclass=_DialogueMeta):
             "role": self._role.value,
             "incoming_messages": [i.json() for i in self._incoming_messages],
             "outgoing_messages": [i.json() for i in self._outgoing_messages],
+            "last_message_id": self._last_message_id,
+            "ordered_message_ids": self._ordered_message_ids,
         }
         return data
 
@@ -407,6 +413,11 @@ class Dialogue(metaclass=_DialogueMeta):
             obj._outgoing_messages = [  # pylint: disable=protected-access
                 message_class.from_json(i) for i in data["outgoing_messages"]
             ]
+            last_message_id = int(data["last_message_id"])
+            obj._last_message_id = last_message_id  # pylint: disable=protected-access
+            obj._ordered_message_ids = [  # pylint: disable=protected-access
+                int(el) for el in data["ordered_message_ids"]
+            ]
             return obj
         except KeyError:  # pragma: nocover
             raise ValueError(f"Dialogue representation is invalid: {data}")
@@ -517,23 +528,15 @@ class Dialogue(metaclass=_DialogueMeta):
 
         :return: the last message if it exists, None otherwise
         """
-        last_message = None  # type: Optional[Message]
-        if (
-            self.last_incoming_message is not None
-            and self.last_outgoing_message is not None
-        ):
-            last_message = (
-                self.last_outgoing_message
-                if self.last_outgoing_message.message_id
-                > self.last_incoming_message.message_id
-                else self.last_incoming_message
-            )
-        elif self.last_incoming_message is not None:
-            last_message = self.last_incoming_message
-        elif self.last_outgoing_message is not None:
-            last_message = self.last_outgoing_message
+        if self._last_message_id is None:
+            return None
 
-        return last_message
+        if (
+            self.last_incoming_message
+            and self.last_incoming_message.message_id == self._last_message_id
+        ):
+            return self.last_incoming_message
+        return self.last_outgoing_message
 
     @property
     def is_empty(self) -> bool:
@@ -574,23 +577,6 @@ class Dialogue(metaclass=_DialogueMeta):
         """
         return not self._is_message_by_self(message)
 
-    def _try_get_message(self, message_id: int) -> Optional[Message]:
-        """
-        Try to get the message whose id is 'message_id'.
-
-        :param message_id: the id of the message
-        :return: the message if it exists, None otherwise
-        """
-        result = None  # type: Optional[Message]
-        list_of_all_messages = itertools.chain(
-            self._outgoing_messages, self._incoming_messages
-        )
-        for message in list_of_all_messages:
-            if message.message_id == message_id:
-                result = message
-                break
-        return result
-
     def _get_message(self, message_id: int) -> Message:
         """
         Get the message whose id is 'message_id'.
@@ -599,7 +585,7 @@ class Dialogue(metaclass=_DialogueMeta):
         :return: the message
         :raises: AssertionError if message is not present
         """
-        message = self._try_get_message(message_id)
+        message = self.get_message_by_id(message_id)
         if message is None:
             raise ValueError("Message not present.")
         return message
@@ -611,10 +597,7 @@ class Dialogue(metaclass=_DialogueMeta):
         :param message_id: the message id
         :return: True if message with that id exists in this dialogue, False otherwise
         """
-        if self.is_empty:
-            return False
-
-        return self.STARTING_MESSAGE_ID <= message_id <= self.last_message.message_id  # type: ignore
+        return self.get_message_by_id(message_id) is not None
 
     def _update(self, message: Message) -> None:
         """
@@ -651,6 +634,9 @@ class Dialogue(metaclass=_DialogueMeta):
         else:
             self._incoming_messages.append(message)
 
+        self._last_message_id = message.message_id
+        self._ordered_message_ids.append(message.message_id)
+
         if message.performative in self.rules.terminal_performatives:
             for fn in self._terminal_state_callbacks:
                 fn(self)
@@ -685,7 +671,7 @@ class Dialogue(metaclass=_DialogueMeta):
         performative: Message.Performative,
         target_message: Optional[Message] = None,
         target: Optional[int] = None,
-        **kwargs,
+        **kwargs: Any,
     ) -> Message:
         """
         Reply to the 'target_message' in this dialogue with a message with 'performative', and contents from kwargs.
@@ -720,7 +706,7 @@ class Dialogue(metaclass=_DialogueMeta):
 
         reply = self._message_class(
             dialogue_reference=self.dialogue_label.dialogue_reference,
-            message_id=last_message.message_id + 1,
+            message_id=self.get_outgoing_next_message_id(),
             target=target,
             performative=performative,
             **kwargs,
@@ -749,13 +735,6 @@ class Dialogue(metaclass=_DialogueMeta):
         if not is_basic_validated:
             return False, msg_basic_validation
 
-        (
-            result_additional_validation,
-            msg_additional_validation,
-        ) = self._additional_validation(message)
-        if not result_additional_validation:
-            return False, msg_additional_validation
-
         result_is_valid, msg_is_valid = self._custom_validation(message)
         if not result_is_valid:
             return False, msg_is_valid
@@ -792,7 +771,6 @@ class Dialogue(metaclass=_DialogueMeta):
         """
         dialogue_reference = message.dialogue_reference
         message_id = message.message_id
-        target = message.target
         performative = message.performative
 
         if dialogue_reference[0] != self.dialogue_label.dialogue_reference[0]:
@@ -811,13 +789,9 @@ class Dialogue(metaclass=_DialogueMeta):
                 ),
             )
 
-        if target != Dialogue.STARTING_TARGET:
-            return (
-                False,
-                "Invalid target. Expected {}. Found {}.".format(
-                    Dialogue.STARTING_TARGET, target
-                ),
-            )
+        err = self._validate_message_target(message)
+        if err:
+            return False, err
 
         if performative not in self.rules.initial_performatives:
             return (
@@ -845,9 +819,6 @@ class Dialogue(metaclass=_DialogueMeta):
         :return: Boolean result, and associated message.
         """
         dialogue_reference = message.dialogue_reference
-        message_id = message.message_id
-        target = message.target
-        performative = message.performative
 
         if dialogue_reference[0] != self.dialogue_label.dialogue_reference[0]:
             return (
@@ -857,66 +828,128 @@ class Dialogue(metaclass=_DialogueMeta):
                 ),
             )
 
-        last_message_id = self.last_message.message_id  # type: ignore
-        if message_id != last_message_id + 1:
-            return (
-                False,
-                "Invalid message_id. Expected {}. Found {}.".format(
-                    last_message_id + 1, message_id
-                ),
-            )
-        if target < 1:
-            return (
-                False,
-                "Invalid target. Expected a value greater than or equal to 1. Found {}.".format(
-                    target
-                ),
-            )
-        if last_message_id < target:
-            return (
-                False,
-                "Invalid target. Expected a value less than or equal to {}. Found {}.".format(
-                    last_message_id, target
-                ),
-            )
+        err = self._validate_message_id(message)
+        if err:
+            return False, err
 
-        target_message = self._get_message(target)
-        target_performative = target_message.performative
-        if performative not in self.rules.get_valid_replies(target_performative):
-            return (
-                False,
-                "Invalid performative. Expected one of {}. Found {}.".format(
-                    self.rules.get_valid_replies(target_performative), performative
-                ),
-            )
+        err = self._validate_message_target(message)
+        if err:
+            return False, err
 
         return True, "The non-initial message passes basic validation."
 
-    def _additional_validation(self, message: Message) -> Tuple[bool, str]:
-        """
-        Check whether 'message' is a valid next message in the dialogue, according to additional rules.
+    def _validate_message_target(self, message: Message) -> Optional[str]:
+        """Check message target corresponds to messages in the dialogue, if not return error string."""
+        target = message.target
+        performative = message.performative
 
-        These rules are designed to be less fundamental than basic rules and subject to change.
-        Currently the following is enforced:
+        if message.message_id == self.STARTING_MESSAGE_ID:
+            # for initial message!
+            if target == self.STARTING_TARGET:
+                # no need to check in details
+                return None
+            return "Invalid target. Expected 0. Found {}.".format(target)
 
-         - A message targets the message strictly before it in the dialogue
+        if (
+            message.message_id != self.STARTING_MESSAGE_ID
+            and target == self.STARTING_TARGET
+        ):
+            return "Invalid target. Expected a non-zero integer. Found {}.".format(
+                target
+            )
 
-        :param message: the message to be validated
-        :return: Boolean result, and associated message.
-        """
+        # quick target check.
+        latest_ids: List[int] = []
+
+        if self.last_incoming_message:
+            latest_ids.append(abs(self.last_incoming_message.message_id))
+
+        if self.last_outgoing_message:
+            latest_ids.append(abs(self.last_outgoing_message.message_id))
+
+        if abs(target) > max(latest_ids):
+            return "Invalid target. Expected a value less than or equal to abs({}). Found abs({}).".format(
+                max(latest_ids), abs(target)
+            )
+
+        # detailed target check
+        target_message = self.get_message_by_id(target)
+
+        if not target_message:
+            return "Invalid target {}. target_message can not be found.".format(
+                target
+            )  # pragma: nocover
+
+        target_performative = target_message.performative
+        if performative not in self.rules.get_valid_replies(target_performative):
+            return "Invalid performative. Expected one of {}. Found {}.".format(
+                self.rules.get_valid_replies(target_performative), performative
+            )
+
+        return None
+
+    def _validate_message_id(self, message: Message) -> Optional[str]:
+        """Check message id corresponds to message id sequences, if not return error string."""
+        is_outgoing = message.to != self.self_address
+
+        # This assumes that messages sent by the opponent are sent in the right order.
+        if is_outgoing:
+            next_message_id = self.get_outgoing_next_message_id()
+        else:
+            next_message_id = self.get_incoming_next_message_id()
+
+        # we know what is the next message id for incoming and outgoing!
+        if message.message_id != next_message_id:
+            return "Invalid message_id. Expected {}. Found {}.".format(
+                next_message_id, message.message_id
+            )
+
+        return None
+
+    def get_message_by_id(self, message_id: int) -> Optional[Message]:
+        """Get message by id, if not presents return None."""
         if self.is_empty:
-            return True, "The message passes additional validation."
+            return None
 
-        last_target = self.last_message.target  # type: ignore
-        if message.target == last_target + 1:
-            return True, "The message passes additional validation."
+        if message_id == 0:
+            raise ValueError("message_id == 0 is invalid!")  # pragma: nocover
 
-        return (
-            False,
-            "Invalid target. Expected {}. Found {}.".format(
-                last_target + 1, message.target
-            ),
-        )
+        if bool(message_id > 0) == self.is_self_initiated:
+            messages_list = self._outgoing_messages
+        else:
+            messages_list = self._incoming_messages
+
+        if len(messages_list) == 0:
+            return None
+
+        if abs(message_id) > abs(messages_list[-1].message_id):
+            return None
+
+        return messages_list[abs(message_id) - 1]
+
+    def get_outgoing_next_message_id(self) -> int:
+        """Get next outgoing message id."""
+        next_message_id = Dialogue.STARTING_MESSAGE_ID
+
+        if self.last_outgoing_message:
+            next_message_id = abs(self.last_outgoing_message.message_id) + 1
+
+        if not self.is_self_initiated:
+            next_message_id = 0 - next_message_id
+
+        return next_message_id
+
+    def get_incoming_next_message_id(self) -> int:
+        """Get next incoming message id."""
+        next_message_id = Dialogue.STARTING_MESSAGE_ID
+
+        if self.last_incoming_message:
+            next_message_id = abs(self.last_incoming_message.message_id) + 1
+
+        if self.is_self_initiated:
+            next_message_id = 0 - next_message_id
+
+        return next_message_id
 
     def _update_dialogue_label(self, final_dialogue_label: DialogueLabel) -> None:
         """
@@ -946,37 +979,19 @@ class Dialogue(metaclass=_DialogueMeta):
         """
         return True, "The message passes custom validation."
 
-    @staticmethod
-    def _interleave(list_1, list_2) -> List:
-        all_elements = [
-            element
-            for element in itertools.chain(*itertools.zip_longest(list_1, list_2))
-            if element is not None
-        ]
-
-        return all_elements
-
     def __str__(self) -> str:
         """
         Get the string representation.
 
         :return: The string representation of the dialogue
         """
-        representation = "Dialogue Label: " + str(self.dialogue_label) + "\n"
+        representation = f"Dialogue Label:\n{self.dialogue_label}\nMessages:\n"
 
-        if self.is_self_initiated:
-            all_messages = self._interleave(
-                self._outgoing_messages, self._incoming_messages
-            )
-        else:
-            all_messages = self._interleave(
-                self._incoming_messages, self._outgoing_messages
-            )
-
-        for msg in all_messages:
-            representation += str(msg.performative) + "( )\n"
-
-        representation = representation[:-1]
+        for msg_id in self._ordered_message_ids:
+            msg = self.get_message_by_id(msg_id)
+            if msg is None:  # pragma: nocover
+                raise ValueError("Dialogue inconsistent! Missing message.")
+            representation += f"message_id={msg.message_id}, target={msg.target}, performative={msg.performative}\n"
         return representation
 
 
@@ -1025,7 +1040,7 @@ class DialogueStats:
             self._other_initiated[end_state] += 1
 
 
-def find_caller_object(object_type: Type):
+def find_caller_object(object_type: Type) -> Any:
     """Find caller object of certain type in the call stack."""
     caller_object = None
     for frame_info in inspect.stack():
@@ -1164,7 +1179,9 @@ class BasicDialoguesStorage:
         return dialogue_label in self._incomplete_to_complete_dialogue_labels
 
     def set_incomplete_dialogue(
-        self, incomplete_dialogue_label, complete_dialogue_label
+        self,
+        incomplete_dialogue_label: DialogueLabel,
+        complete_dialogue_label: DialogueLabel,
     ) -> None:
         """Set incomplete dialogue label."""
         self._incomplete_to_complete_dialogue_labels[
@@ -1631,7 +1648,7 @@ class Dialogues:
         return cls._generate_dialogue_nonce(), Dialogue.UNASSIGNED_DIALOGUE_REFERENCE
 
     def create(
-        self, counterparty: Address, performative: Message.Performative, **kwargs,
+        self, counterparty: Address, performative: Message.Performative, **kwargs: Any,
     ) -> Tuple[Message, Dialogue]:
         """
         Create a dialogue with 'counterparty', with an initial message whose performative is 'performative' and contents are from 'kwargs'.
@@ -1703,8 +1720,8 @@ class Dialogues:
             dialogue._update(initial_message)  # pylint: disable=protected-access
         except InvalidDialogueMessage as e:
             self._dialogues_storage.remove(dialogue.dialogue_label)
-            raise SyntaxError(
-                "Cannot create a dialogue with the specified performative and contents."
+            raise ValueError(
+                f"Cannot create a dialogue with the specified performative and contents. {e}"
             ) from e
         return dialogue
 
@@ -1740,12 +1757,13 @@ class Dialogues:
         is_new_dialogue = (
             dialogue_reference[0] != Dialogue.UNASSIGNED_DIALOGUE_REFERENCE
             and dialogue_reference[1] == Dialogue.UNASSIGNED_DIALOGUE_REFERENCE
-            and message.message_id == 1
+            and message.message_id == Dialogue.STARTING_MESSAGE_ID
         )
         is_incomplete_label_and_non_initial_msg = (
             dialogue_reference[0] != Dialogue.UNASSIGNED_DIALOGUE_REFERENCE
             and dialogue_reference[1] == Dialogue.UNASSIGNED_DIALOGUE_REFERENCE
-            and message.message_id > 1
+            and message.message_id
+            not in (Dialogue.STARTING_MESSAGE_ID, Dialogue.STARTING_TARGET)
         )
 
         if is_invalid_label:
@@ -1778,7 +1796,6 @@ class Dialogues:
         else:
             # couldn't find the dialogue referenced by the message
             result = None
-
         return result
 
     def _complete_dialogue_reference(self, message: Message) -> None:
@@ -1849,10 +1866,10 @@ class Dialogues:
             other_initiated_dialogue_label
         )
 
-        self_initiated_dialogue = self._get_dialogue_from_label(
+        self_initiated_dialogue = self.get_dialogue_from_label(
             self_initiated_dialogue_label
         )
-        other_initiated_dialogue = self._get_dialogue_from_label(
+        other_initiated_dialogue = self.get_dialogue_from_label(
             other_initiated_dialogue_label
         )
 
@@ -1868,7 +1885,7 @@ class Dialogues:
         """
         return self._dialogues_storage.get_latest_label(dialogue_label)
 
-    def _get_dialogue_from_label(
+    def get_dialogue_from_label(
         self, dialogue_label: DialogueLabel
     ) -> Optional[Dialogue]:
         """
