@@ -21,7 +21,7 @@
 
 import asyncio
 import logging
-from typing import Dict, Optional, Tuple, Union, cast
+from typing import Any, Dict, Optional, Tuple, Union, cast
 
 import aioprometheus  # type: ignore
 
@@ -39,7 +39,7 @@ from packages.fetchai.protocols.prometheus.dialogues import (
 from packages.fetchai.protocols.prometheus.message import PrometheusMessage
 
 
-PUBLIC_ID = PublicId.from_str("fetchai/prometheus:0.2.0")
+PUBLIC_ID = PublicId.from_str("fetchai/prometheus:0.3.0")
 
 DEFAULT_HOST = "127.0.0.1"
 DEFAULT_PORT = 9090
@@ -50,7 +50,7 @@ VALID_METRIC_TYPES = {"Counter", "Gauge", "Histogram", "Summary"}
 class PrometheusDialogues(BasePrometheusDialogues):
     """The dialogues class keeps track of all prometheus dialogues."""
 
-    def __init__(self, **kwargs) -> None:
+    def __init__(self, **kwargs: Any) -> None:
         """
         Initialize dialogues.
 
@@ -145,9 +145,12 @@ class PrometheusChannel:
         """
         sender = envelope.sender
         self.logger.debug("Processing message from {}: {}".format(sender, envelope))
-        if envelope.protocol_id != PrometheusMessage.protocol_id:
+        if (
+            envelope.protocol_specification_id
+            != PrometheusMessage.protocol_specification_id
+        ):
             raise ValueError(
-                f"Protocol {envelope.protocol_id} is not valid for prometheus."
+                f"Protocol {envelope.protocol_specification_id} is not valid for prometheus."
             )
         await self._handle_prometheus_message(envelope)
 
@@ -187,13 +190,7 @@ class PrometheusChannel:
             message=response_msg,
         )
         context = cast(EnvelopeContext, envelope.context)
-        envelope = Envelope(
-            to=msg.to,
-            sender=msg.sender,
-            protocol_id=msg.protocol_id,
-            message=msg,
-            context=context,
-        )
+        envelope = Envelope(to=msg.to, sender=msg.sender, message=msg, context=context,)
         await self._send(envelope)
 
     async def _handle_add_metric(self, message: PrometheusMessage) -> Tuple[int, str]:
@@ -285,7 +282,7 @@ class PrometheusConnection(Connection):
 
     connection_id = PUBLIC_ID
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs: Any) -> None:
         """
         Initialize a connection to a local prometheus server.
 
@@ -293,7 +290,7 @@ class PrometheusConnection(Connection):
         """
         super().__init__(**kwargs)
 
-        self.host = cast(int, self.configuration.config.get("host", DEFAULT_HOST))
+        self.host = cast(str, self.configuration.config.get("host", DEFAULT_HOST))
         self.port = cast(int, self.configuration.config.get("port", DEFAULT_PORT))
         self.channel = PrometheusChannel(
             self.address, self.host, self.port, self.logger
@@ -310,9 +307,9 @@ class PrometheusConnection(Connection):
 
         with self._connect_context():
             self.channel.logger = self.logger
-            self._state.set(ConnectionStates.connecting)
+            self.state = ConnectionStates.connecting
             await self.channel.connect()
-            self._state.set(ConnectionStates.connected)
+            self.state = ConnectionStates.connected
 
     async def disconnect(self) -> None:
         """
@@ -323,9 +320,9 @@ class PrometheusConnection(Connection):
         if self.is_disconnected:  # pragma: nocover
             return
 
-        self._state.set(ConnectionStates.disconnecting)
+        self.state = ConnectionStates.disconnecting
         await self.channel.disconnect()
-        self._state.set(ConnectionStates.disconnected)
+        self.state = ConnectionStates.disconnected
 
     async def send(self, envelope: Envelope) -> None:
         """
@@ -337,7 +334,7 @@ class PrometheusConnection(Connection):
         self._ensure_connected()
         await self.channel.send(envelope)
 
-    async def receive(self, *args, **kwargs) -> Optional["Envelope"]:
+    async def receive(self, *args: Any, **kwargs: Any) -> Optional["Envelope"]:
         """
         Receive an envelope.
 
