@@ -16,8 +16,8 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-"""Extension to the Simple OEF and OEF Python SDK."""
 
+"""Extension to the Simple OEF and OEF Python SDK."""
 import asyncio
 import copy
 import logging
@@ -30,17 +30,17 @@ from concurrent.futures.thread import ThreadPoolExecutor
 from contextlib import suppress
 from enum import Enum
 from pathlib import Path
-from typing import Callable, Dict, List, Optional, Set, Type, Union, cast
+from typing import Any, Callable, Dict, List, Optional, Type, Union, cast
 from urllib import parse
 from uuid import uuid4
 
-import requests
 from defusedxml import ElementTree as ET  # pylint: disable=wrong-import-order
 
 from aea.common import Address
 from aea.configurations.base import PublicId
 from aea.connections.base import Connection, ConnectionStates
 from aea.exceptions import enforce
+from aea.helpers import http_requests as requests
 from aea.helpers.search.models import (
     Constraint,
     ConstraintTypes,
@@ -68,7 +68,7 @@ from packages.fetchai.protocols.oef_search.message import OefSearchMessage
 
 _default_logger = logging.getLogger("aea.packages.fetchai.connections.soef")
 
-PUBLIC_ID = PublicId.from_str("fetchai/soef:0.15.0")
+PUBLIC_ID = PublicId.from_str("fetchai/soef:0.16.0")
 
 NOT_SPECIFIED = object()
 
@@ -224,8 +224,7 @@ class SOEFChannel:
         api_key: str,
         soef_addr: str,
         soef_port: int,
-        excluded_protocols: Set[PublicId],
-        restricted_to_protocols: Set[PublicId],
+        data_dir: str,
         chain_identifier: Optional[str] = None,
         token_storage_path: Optional[str] = None,
         logger: logging.Logger = _default_logger,
@@ -237,8 +236,6 @@ class SOEFChannel:
         :param api_key: the SOEF API key.
         :param soef_addr: the SOEF IP address.
         :param soef_port: the SOEF port.
-        :param excluded_protocols: the protocol ids excluded
-        :param restricted_to_protocols: the protocol ids restricted to
         :param chain_identifier: supported chain id
         """
         if chain_identifier is not None and not any(
@@ -253,13 +250,14 @@ class SOEFChannel:
         self.soef_addr = soef_addr
         self.soef_port = soef_port
         self.base_url = "http://{}:{}".format(soef_addr, soef_port)
-        self.excluded_protocols = excluded_protocols
-        self.restricted_to_protocols = restricted_to_protocols
         self.oef_search_dialogues = OefSearchDialogues()
 
         self._token_storage_path = token_storage_path
         if self._token_storage_path is not None:
-            self._token_storage_path = os.path.abspath(self._token_storage_path)
+            if not Path(self._token_storage_path).is_absolute():
+                self._token_storage_path = os.path.abspath(
+                    os.path.join(data_dir, self._token_storage_path)
+                )
             Path(self._token_storage_path).touch()
         self.declared_name = uuid4().hex
         self._unique_page_address = None  # type: Optional[str]
@@ -412,28 +410,6 @@ class SOEFChannel:
             return {}
         return {"skfilter": filters}
 
-    def _check_protocol_valid(self, envelope: Envelope) -> None:
-        """
-        Check protocol is supported and raises ValueError if not.
-
-        :param envelope: envelope to check protocol of
-        :return: None
-        """
-        is_in_excluded = envelope.protocol_id in (self.excluded_protocols or [])
-        is_in_restricted = not self.restricted_to_protocols or envelope.protocol_id in (
-            self.restricted_to_protocols or []
-        )
-
-        if is_in_excluded or not is_in_restricted:
-            self.logger.error(
-                "This envelope cannot be sent with the soef connection: protocol_id={}".format(
-                    envelope.protocol_id
-                )
-            )
-            raise ValueError(
-                "Cannot send message, invalid protocol: {}".format(envelope.protocol_id)
-            )
-
     async def send(self, envelope: Envelope) -> None:
         """
         Send message handler.
@@ -441,13 +417,12 @@ class SOEFChannel:
         :param envelope: the envelope.
         :return: None
         """
-        self._check_protocol_valid(envelope)
         await self.process_envelope(envelope)
 
-    async def _request_text(self, *args, **kwargs) -> str:
+    async def _request_text(self, *args: Any, **kwargs: Any) -> str:
         """Perform and http request and return text of response."""
-        # pydocstyle fix. cause black reformat.
-        def _do_request():
+
+        def _do_request() -> str:
             return requests.request(*args, **kwargs).text
 
         return await self.loop.run_in_executor(self._executor_pool, _do_request)
@@ -602,7 +577,6 @@ class SOEFChannel:
         envelope = Envelope(
             to=message.to,
             sender=message.sender,
-            protocol_id=message.protocol_id,
             message=message,
             context=oef_search_dialogue.envelope_context,
         )
@@ -828,7 +802,7 @@ class SOEFChannel:
 
         await self._set_personality_piece(piece, value)
 
-    async def _set_personality_piece(self, piece: str, value: str):
+    async def _set_personality_piece(self, piece: str, value: str) -> None:
         """
         Set the personality piece.
 
@@ -922,7 +896,6 @@ class SOEFChannel:
         envelope = Envelope(
             to=message.to,
             sender=message.sender,
-            protocol_id=message.protocol_id,
             message=message,
             context=oef_search_dialogue.envelope_context,
         )
@@ -1156,7 +1129,6 @@ class SOEFChannel:
         envelope = Envelope(
             to=message.to,
             sender=message.sender,
-            protocol_id=message.protocol_id,
             message=message,
             context=oef_search_dialogue.envelope_context,
         )
@@ -1168,7 +1140,7 @@ class SOEFConnection(Connection):
 
     connection_id = PUBLIC_ID
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs: Any) -> None:
         """Initialize."""
         if kwargs.get("configuration") is None:  # pragma: nocover
             kwargs["excluded_protocols"] = kwargs.get("excluded_protocols") or []
@@ -1195,8 +1167,7 @@ class SOEFConnection(Connection):
             self.api_key,
             self.soef_addr,
             self.soef_port,
-            self.excluded_protocols,
-            self.restricted_to_protocols,
+            data_dir=self.data_dir,
             chain_identifier=chain_identifier,
             token_storage_path=token_storage_path,
         )
@@ -1229,11 +1200,11 @@ class SOEFConnection(Connection):
             return
         if self.in_queue is None:
             raise ValueError("In queue not set.")  # pragma: nocover
-        self._state.set(ConnectionStates.disconnecting)
+        self.state = ConnectionStates.disconnecting
         await self.channel.disconnect()
-        self._state.set(ConnectionStates.disconnected)
+        self.state = ConnectionStates.disconnected
 
-    async def receive(self, *args, **kwargs) -> Optional["Envelope"]:
+    async def receive(self, *args: Any, **kwargs: Any) -> Optional["Envelope"]:
         """
         Receive an envelope. Blocking.
 
