@@ -20,7 +20,7 @@
 """This module contains fipa's message definition."""
 
 import logging
-from typing import Dict, Set, Tuple, cast
+from typing import Any, Dict, Set, Tuple, cast
 
 from aea.configurations.base import PublicId
 from aea.exceptions import AEAEnforceError, enforce
@@ -40,7 +40,8 @@ DEFAULT_BODY_SIZE = 4
 class FipaMessage(Message):
     """A protocol for FIPA ACL."""
 
-    protocol_id = PublicId.from_str("fetchai/fipa:0.12.0")
+    protocol_id = PublicId.from_str("fetchai/fipa:0.13.0")
+    protocol_specification_id = PublicId.from_str("fetchai/fipa:0.1.0")
 
     Description = CustomDescription
 
@@ -59,7 +60,7 @@ class FipaMessage(Message):
         MATCH_ACCEPT_W_INFORM = "match_accept_w_inform"
         PROPOSE = "propose"
 
-        def __str__(self):
+        def __str__(self) -> str:
             """Get the string representation."""
             return str(self.value)
 
@@ -93,7 +94,7 @@ class FipaMessage(Message):
         dialogue_reference: Tuple[str, str] = ("", ""),
         message_id: int = 1,
         target: int = 0,
-        **kwargs,
+        **kwargs: Any,
     ):
         """
         Initialise an instance of FipaMessage.
@@ -308,13 +309,6 @@ class FipaMessage(Message):
                         self.target
                     ),
                 )
-            else:
-                enforce(
-                    0 < self.target < self.message_id,
-                    "Invalid 'target'. Expected an integer between 1 and {} inclusive. Found {}.".format(
-                        self.message_id - 1, self.target,
-                    ),
-                )
         except (AEAEnforceError, ValueError, KeyError) as e:
             _default_logger.error(str(e))
             return False
