@@ -20,7 +20,7 @@
 """This module contains gym's message definition."""
 
 import logging
-from typing import Dict, Set, Tuple, cast
+from typing import Any, Dict, Set, Tuple, cast
 
 from aea.configurations.base import PublicId
 from aea.exceptions import AEAEnforceError, enforce
@@ -37,7 +37,8 @@ DEFAULT_BODY_SIZE = 4
 class GymMessage(Message):
     """A protocol for interacting with a gym connection."""
 
-    protocol_id = PublicId.from_str("fetchai/gym:0.11.0")
+    protocol_id = PublicId.from_str("fetchai/gym:0.12.0")
+    protocol_specification_id = PublicId.from_str("fetchai/gym:0.1.0")
 
     AnyObject = CustomAnyObject
 
@@ -50,7 +51,7 @@ class GymMessage(Message):
         RESET = "reset"
         STATUS = "status"
 
-        def __str__(self):
+        def __str__(self) -> str:
             """Get the string representation."""
             return str(self.value)
 
@@ -78,7 +79,7 @@ class GymMessage(Message):
         dialogue_reference: Tuple[str, str] = ("", ""),
         message_id: int = 1,
         target: int = 0,
-        **kwargs,
+        **kwargs: Any,
     ):
         """
         Initialise an instance of GymMessage.
@@ -301,13 +302,6 @@ class GymMessage(Message):
                         self.target
                     ),
                 )
-            else:
-                enforce(
-                    0 < self.target < self.message_id,
-                    "Invalid 'target'. Expected an integer between 1 and {} inclusive. Found {}.".format(
-                        self.message_id - 1, self.target,
-                    ),
-                )
         except (AEAEnforceError, ValueError, KeyError) as e:
             _default_logger.error(str(e))
             return False
