@@ -20,7 +20,7 @@
 """This module contains ledger_api's message definition."""
 
 import logging
-from typing import Optional, Set, Tuple, cast
+from typing import Any, Optional, Set, Tuple, cast
 
 from aea.configurations.base import PublicId
 from aea.exceptions import AEAEnforceError, enforce
@@ -51,7 +51,8 @@ DEFAULT_BODY_SIZE = 4
 class LedgerApiMessage(Message):
     """A protocol for ledger APIs requests and responses."""
 
-    protocol_id = PublicId.from_str("fetchai/ledger_api:0.9.0")
+    protocol_id = PublicId.from_str("fetchai/ledger_api:0.10.0")
+    protocol_specification_id = PublicId.from_str("fetchai/ledger_api:0.1.0")
 
     Kwargs = CustomKwargs
 
@@ -82,7 +83,7 @@ class LedgerApiMessage(Message):
         TRANSACTION_DIGEST = "transaction_digest"
         TRANSACTION_RECEIPT = "transaction_receipt"
 
-        def __str__(self):
+        def __str__(self) -> str:
             """Get the string representation."""
             return str(self.value)
 
@@ -130,7 +131,7 @@ class LedgerApiMessage(Message):
         dialogue_reference: Tuple[str, str] = ("", ""),
         message_id: int = 1,
         target: int = 0,
-        **kwargs,
+        **kwargs: Any,
     ):
         """
         Initialise an instance of LedgerApiMessage.
@@ -489,13 +490,6 @@ class LedgerApiMessage(Message):
                         self.target
                     ),
                 )
-            else:
-                enforce(
-                    0 < self.target < self.message_id,
-                    "Invalid 'target'. Expected an integer between 1 and {} inclusive. Found {}.".format(
-                        self.message_id - 1, self.target,
-                    ),
-                )
         except (AEAEnforceError, ValueError, KeyError) as e:
             _default_logger.error(str(e))
             return False
