@@ -48,7 +48,7 @@ EXPIRATION_BLOCK = 1000000000000000
 class SimpleOracleBehaviour(TickerBehaviour):
     """This class implements a behaviour that deploys a Fetch oracle contract."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs: Any):
         """Initialise the behaviour."""
         update_interval = kwargs.pop(
             "update_interval", DEFAULT_UPDATE_INTERVAL
@@ -226,7 +226,7 @@ class SimpleOracleBehaviour(TickerBehaviour):
         )
         self.context.logger.info("requesting update transaction...")
 
-    def _get_balance(self):
+    def _get_balance(self) -> None:
         """
         Request balance of agent account by sending a message to the ledger API
 
