@@ -71,18 +71,19 @@ _._ensure_valid_envelope_for_external_comms  # unused method (aea/connections/ba
 _._connect_context  # unused method (aea/connections/base.py:125)
 _.has_crypto_store  # unused property (aea/connections/base.py:138)
 _.from_dir  # unused method (aea/connections/base.py:200)
-MyScaffoldConnection  # unused class (aea/connections/scaffold/connection.py:31)
+MyScaffoldAsyncConnection  # unused class (aea/connections/scaffold/connection.py:31)
 _.get_instance  # unused method (aea/contracts/base.py:64)
 _.from_dir  # unused method (aea/contracts/base.py:81)
 _.get_raw_transaction  # unused method (aea/contracts/base.py:147)
 _.get_raw_message  # unused method (aea/contracts/base.py:163)
 MyScaffoldContract  # unused class (aea/contracts/scaffold/contract.py:25)
 _.is_valid_address  # aea/crypto/cosmos.py:170: unused method 'is_valid_address' (60% confidence)
-_.get_init_transaction  # unused method (aea/crypto/cosmos.py:437)
 _.get_handle_transaction  # unused method (aea/crypto/cosmos.py:491)
 _.execute_contract_query  # unused method (aea/crypto/cosmos.py:571)
+_.get_code_id  # unused method (aea/crypto/cosmos.py:837)
 _.get_last_code_id  # unused method (aea/crypto/cosmos.py:837)
 _.get_contract_address  # unused method (aea/crypto/cosmos.py:849)
+_.get_last_contract_address  # unused method (aea/crypto/cosmos.py:849)
 CosmosFaucetApi  # unused class (aea/crypto/cosmos.py:867)
 testnet_name  # unused variable (aea/crypto/cosmos.py:871)
 EthereumFaucetApi  # unused class (aea/crypto/ethereum.py:507)
@@ -93,7 +94,6 @@ _.has_ledger  # unused method (aea/crypto/ledger_apis.py:55)
 _.get_api  # unused method (aea/crypto/ledger_apis.py:60)
 _.has_spec  # unused method (aea/crypto/registries/base.py:236)
 _.main_cryptos  # unused property (aea/crypto/wallet.py:130)
-AwaitableProc  # unused class (aea/helpers/async_utils.py:391)
 locate  # unused function (aea/helpers/base.py:139)
 sigint_crossplatform  # unused function (aea/helpers/base.py:236)
 _.dwFlags  # unused attribute (aea/helpers/base.py:269)
@@ -247,3 +247,6 @@ Uri  # unused class (aea/helpers/acn/uri.py:26)
 not_before_string  # unused property (aea/helpers/base.py:724)
 not_after_string  # unused property (aea/helpers/base.py:729)
 from_cert_request  # unused method (aea/helpers/acn/agent_record.py:136)
+BaseSyncConnection  # unused class (aea/connections/sync_connection.py:33)
+_.put_envelope  # unused method (aea/connections/sync_connection.py:84)
+MyScaffoldSyncConnection  # unused class (aea/connections/scaffold/connection.py:89)
