@@ -244,6 +244,7 @@ class TestSkillConfig:
         )
         assert expected_dummy_handler_args == skill_config.handlers.read("dummy").args
         assert expected_dummy_model_args == skill_config.models.read("dummy").args
+        assert len(skill_config.package_dependencies)
 
     def test_update_method_raises_error_if_skill_component_not_allowed(self):
         """Test that we raise error if the custom configuration contain unexpected skill components."""
@@ -996,6 +997,14 @@ def test_check_public_id_consistency_negative():
         component_configuration.check_public_id_consistency(Path(random_dir_name))
 
 
+def test_check_public_id_consistency_positive():
+    """Test ComponentId.check_public_id_consistency works."""
+    skill_config_path = Path(DUMMY_SKILL_PATH)
+    loader = ConfigLoaders.from_package_type(PackageType.SKILL)
+    skill_config = loader.load(skill_config_path.open())
+    skill_config.check_public_id_consistency(Path(skill_config_path).parent)
+
+
 def test_component_id_from_json():
     """Test ComponentId.from_json."""
     json_data = {
