@@ -25,12 +25,14 @@ from pathlib import Path
 from unittest.mock import MagicMock, patch
 
 import pytest
+from web3._utils.request import _session_cache as session_cache
 
 from aea.crypto.ethereum import (
     AttributeDictTranslator,
     EthereumApi,
     EthereumCrypto,
     EthereumFaucetApi,
+    LruLockWrapper,
 )
 
 from tests.conftest import (
@@ -315,3 +317,13 @@ def test_ethereum_api_get_deploy_transaction(*args):
             )
             is None
         )
+
+
+def test_session_cache():
+    """Test session cache."""
+    assert isinstance(session_cache, LruLockWrapper)
+
+    session_cache[1] = 1
+    assert session_cache[1] == 1
+    del session_cache[1]
+    assert 1 not in session_cache
