@@ -89,12 +89,7 @@ async def test_erc1155_get_deploy_transaction(erc1155_contract, ledger_apis_conn
         callable="get_deploy_transaction",
         kwargs=ContractApiMessage.Kwargs({"deployer_address": address}),
     )
-    envelope = Envelope(
-        to=request.to,
-        sender=request.sender,
-        protocol_id=request.protocol_id,
-        message=request,
-    )
+    envelope = Envelope(to=request.to, sender=request.sender, message=request,)
 
     await ledger_apis_connection.send(envelope)
     await asyncio.sleep(0.01)
@@ -138,12 +133,7 @@ async def test_erc1155_get_raw_transaction(
             {"deployer_address": address, "token_ids": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]}
         ),
     )
-    envelope = Envelope(
-        to=request.to,
-        sender=request.sender,
-        protocol_id=request.protocol_id,
-        message=request,
-    )
+    envelope = Envelope(to=request.to, sender=request.sender, message=request,)
 
     await ledger_apis_connection.send(envelope)
     await asyncio.sleep(0.01)
@@ -191,12 +181,7 @@ async def test_erc1155_get_raw_message(erc1155_contract, ledger_apis_connection)
             }
         ),
     )
-    envelope = Envelope(
-        to=request.to,
-        sender=request.sender,
-        protocol_id=request.protocol_id,
-        message=request,
-    )
+    envelope = Envelope(to=request.to, sender=request.sender, message=request,)
 
     await ledger_apis_connection.send(envelope)
     await asyncio.sleep(0.01)
@@ -235,12 +220,7 @@ async def test_erc1155_get_state(erc1155_contract, ledger_apis_connection):
             {"agent_address": address, "token_id": token_id}
         ),
     )
-    envelope = Envelope(
-        to=request.to,
-        sender=request.sender,
-        protocol_id=request.protocol_id,
-        message=request,
-    )
+    envelope = Envelope(to=request.to, sender=request.sender, message=request,)
 
     await ledger_apis_connection.send(envelope)
     await asyncio.sleep(0.01)
@@ -325,12 +305,7 @@ async def test_callable_wrong_number_of_arguments_api_and_contract_address(
             {"agent_address": address, "token_id": token_id}
         ),
     )
-    envelope = Envelope(
-        to=request.to,
-        sender=request.sender,
-        protocol_id=request.protocol_id,
-        message=request,
-    )
+    envelope = Envelope(to=request.to, sender=request.sender, message=request,)
 
     with unittest.mock.patch(
         "inspect.getfullargspec", return_value=unittest.mock.MagicMock(args=[None])
@@ -375,12 +350,7 @@ async def test_callable_wrong_number_of_arguments_apis(
         callable="get_deploy_transaction",
         kwargs=ContractApiMessage.Kwargs({}),
     )
-    envelope = Envelope(
-        to=request.to,
-        sender=request.sender,
-        protocol_id=request.protocol_id,
-        message=request,
-    )
+    envelope = Envelope(to=request.to, sender=request.sender, message=request,)
 
     with unittest.mock.patch(
         "inspect.getfullargspec", return_value=unittest.mock.MagicMock(args=[])
@@ -429,12 +399,7 @@ async def test_callable_wrong_number_of_arguments_apis_method_call(
         callable="get_deploy_transaction",
         kwargs=ContractApiMessage.Kwargs({}),
     )
-    envelope = Envelope(
-        to=request.to,
-        sender=request.sender,
-        protocol_id=request.protocol_id,
-        message=request,
-    )
+    envelope = Envelope(to=request.to, sender=request.sender, message=request,)
 
     with unittest.mock.patch.object(
         ledger_apis_connection._contract_dispatcher, "_call_stub", return_value=None
@@ -468,12 +433,7 @@ async def test_callable_generic_error(erc1155_contract, ledger_apis_connection):
             {"agent_address": address, "token_id": token_id}
         ),
     )
-    envelope = Envelope(
-        to=request.to,
-        sender=request.sender,
-        protocol_id=request.protocol_id,
-        message=request,
-    )
+    envelope = Envelope(to=request.to, sender=request.sender, message=request,)
 
     with unittest.mock.patch(
         "inspect.getfullargspec", side_effect=Exception("Generic error")
@@ -513,12 +473,7 @@ async def test_callable_cannot_find(erc1155_contract, ledger_apis_connection, ca
             {"agent_address": address, "token_id": token_id}
         ),
     )
-    envelope = Envelope(
-        to=request.to,
-        sender=request.sender,
-        protocol_id=request.protocol_id,
-        message=request,
-    )
+    envelope = Envelope(to=request.to, sender=request.sender, message=request,)
 
     with caplog.at_level(logging.DEBUG, "aea.packages.fetchai.connections.ledger"):
         await ledger_apis_connection.send(envelope)
