@@ -111,7 +111,9 @@ class TestDefault(UseOef):
         cls.connection = _make_oef_connection(
             FETCHAI_ADDRESS_ONE, oef_addr="127.0.0.1", oef_port=10000,
         )
-        cls.multiplexer = Multiplexer([cls.connection])
+        cls.multiplexer = Multiplexer(
+            [cls.connection], protocols=[FipaMessage, DefaultMessage]
+        )
         cls.multiplexer.connect()
 
     def test_send_message(self):
@@ -124,12 +126,7 @@ class TestDefault(UseOef):
             content=b"hello",
         )
         self.multiplexer.put(
-            Envelope(
-                to=FETCHAI_ADDRESS_ONE,
-                sender=FETCHAI_ADDRESS_ONE,
-                protocol_id=DefaultMessage.protocol_id,
-                message=msg,
-            )
+            Envelope(to=FETCHAI_ADDRESS_ONE, sender=FETCHAI_ADDRESS_ONE, message=msg,)
         )
         recv_msg = self.multiplexer.get(block=True, timeout=3.0)
         assert recv_msg is not None
@@ -151,7 +148,9 @@ class TestOEF(UseOef):
             self.connection = _make_oef_connection(
                 FETCHAI_ADDRESS_ONE, oef_addr="127.0.0.1", oef_port=10000,
             )
-            self.multiplexer = Multiplexer([self.connection])
+            self.multiplexer = Multiplexer(
+                [self.connection], protocols=[FipaMessage, DefaultMessage]
+            )
             self.multiplexer.connect()
             self.oef_search_dialogues = OefSearchDialogues(FETCHAI_ADDRESS_ONE)
 
@@ -172,7 +171,6 @@ class TestOEF(UseOef):
                 Envelope(
                     to=oef_search_request.to,
                     sender=oef_search_request.sender,
-                    protocol_id=oef_search_request.protocol_id,
                     message=oef_search_request,
                 )
             )
@@ -206,7 +204,6 @@ class TestOEF(UseOef):
                 Envelope(
                     to=oef_search_request.to,
                     sender=oef_search_request.sender,
-                    protocol_id=oef_search_request.protocol_id,
                     message=oef_search_request,
                 )
             )
@@ -247,7 +244,6 @@ class TestOEF(UseOef):
                 Envelope(
                     to=oef_search_request.to,
                     sender=oef_search_request.sender,
-                    protocol_id=oef_search_request.protocol_id,
                     message=oef_search_request,
                 )
             )
@@ -275,7 +271,9 @@ class TestOEF(UseOef):
             cls.connection = _make_oef_connection(
                 FETCHAI_ADDRESS_ONE, oef_addr="127.0.0.1", oef_port=10000,
             )
-            cls.multiplexer = Multiplexer([cls.connection])
+            cls.multiplexer = Multiplexer(
+                [cls.connection], protocols=[FipaMessage, DefaultMessage]
+            )
             cls.multiplexer.connect()
             cls.oef_search_dialogues = OefSearchDialogues(FETCHAI_ADDRESS_ONE)
 
@@ -294,7 +292,6 @@ class TestOEF(UseOef):
                 Envelope(
                     to=oef_search_registration.to,
                     sender=oef_search_registration.sender,
-                    protocol_id=OefSearchMessage.protocol_id,
                     message=oef_search_registration,
                 )
             )
@@ -311,7 +308,6 @@ class TestOEF(UseOef):
                 Envelope(
                     to=oef_search_request.to,
                     sender=oef_search_request.sender,
-                    protocol_id=oef_search_request.protocol_id,
                     message=oef_search_request,
                 )
             )
@@ -347,7 +343,9 @@ class TestOEF(UseOef):
             cls.connection = _make_oef_connection(
                 FETCHAI_ADDRESS_ONE, oef_addr="127.0.0.1", oef_port=10000,
             )
-            cls.multiplexer = Multiplexer([cls.connection])
+            cls.multiplexer = Multiplexer(
+                [cls.connection], protocols=[FipaMessage, DefaultMessage]
+            )
             cls.multiplexer.connect()
             cls.oef_search_dialogues = OefSearchDialogues(FETCHAI_ADDRESS_ONE)
 
@@ -365,7 +363,6 @@ class TestOEF(UseOef):
                 Envelope(
                     to=oef_search_registration.to,
                     sender=oef_search_registration.sender,
-                    protocol_id=oef_search_registration.protocol_id,
                     message=oef_search_registration,
                 )
             )
@@ -384,7 +381,6 @@ class TestOEF(UseOef):
                 Envelope(
                     to=oef_search_request.to,
                     sender=oef_search_request.sender,
-                    protocol_id=oef_search_request.protocol_id,
                     message=oef_search_request,
                 )
             )
@@ -417,7 +413,6 @@ class TestOEF(UseOef):
                 Envelope(
                     to=oef_search_deregistration.to,
                     sender=oef_search_deregistration.sender,
-                    protocol_id=oef_search_deregistration.protocol_id,
                     message=oef_search_deregistration,
                 )
             )
@@ -436,7 +431,6 @@ class TestOEF(UseOef):
                 Envelope(
                     to=oef_search_request.to,
                     sender=oef_search_request.sender,
-                    protocol_id=oef_search_request.protocol_id,
                     message=oef_search_request,
                 )
             )
@@ -469,8 +463,12 @@ class TestFIPA(UseOef):
         cls.connection2 = _make_oef_connection(
             FETCHAI_ADDRESS_TWO, oef_addr="127.0.0.1", oef_port=10000,
         )
-        cls.multiplexer1 = Multiplexer([cls.connection1])
-        cls.multiplexer2 = Multiplexer([cls.connection2])
+        cls.multiplexer1 = Multiplexer(
+            [cls.connection1], protocols=[FipaMessage, DefaultMessage]
+        )
+        cls.multiplexer2 = Multiplexer(
+            [cls.connection2], protocols=[FipaMessage, DefaultMessage]
+        )
         cls.multiplexer1.connect()
         cls.multiplexer2.connect()
 
@@ -486,12 +484,7 @@ class TestFIPA(UseOef):
         cfp_message.to = FETCHAI_ADDRESS_TWO
         cfp_message.sender = FETCHAI_ADDRESS_ONE
         self.multiplexer1.put(
-            Envelope(
-                to=cfp_message.to,
-                sender=cfp_message.sender,
-                protocol_id=cfp_message.protocol_id,
-                message=cfp_message,
-            )
+            Envelope(to=cfp_message.to, sender=cfp_message.sender, message=cfp_message,)
         )
         envelope = self.multiplexer2.get(block=True, timeout=5.0)
         expected_cfp_message = FipaMessage.serializer.decode(envelope.message)
@@ -509,12 +502,7 @@ class TestFIPA(UseOef):
         cfp_none.to = FETCHAI_ADDRESS_TWO
         cfp_none.sender = FETCHAI_ADDRESS_ONE
         self.multiplexer1.put(
-            Envelope(
-                to=cfp_none.to,
-                sender=cfp_none.sender,
-                protocol_id=cfp_none.protocol_id,
-                message=cfp_none,
-            )
+            Envelope(to=cfp_none.to, sender=cfp_none.sender, message=cfp_none,)
         )
         envelope = self.multiplexer2.get(block=True, timeout=5.0)
         expected_cfp_none = FipaMessage.serializer.decode(envelope.message)
@@ -535,10 +523,7 @@ class TestFIPA(UseOef):
         propose_empty.sender = FETCHAI_ADDRESS_ONE
         self.multiplexer1.put(
             Envelope(
-                to=propose_empty.to,
-                sender=propose_empty.sender,
-                protocol_id=propose_empty.protocol_id,
-                message=propose_empty,
+                to=propose_empty.to, sender=propose_empty.sender, message=propose_empty,
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
@@ -563,7 +548,6 @@ class TestFIPA(UseOef):
             Envelope(
                 to=propose_descriptions.to,
                 sender=propose_descriptions.sender,
-                protocol_id=propose_descriptions.protocol_id,
                 message=propose_descriptions,
             )
         )
@@ -584,12 +568,7 @@ class TestFIPA(UseOef):
         accept.to = FETCHAI_ADDRESS_TWO
         accept.sender = FETCHAI_ADDRESS_ONE
         self.multiplexer1.put(
-            Envelope(
-                to=accept.to,
-                sender=accept.sender,
-                protocol_id=FipaMessage.protocol_id,
-                message=accept,
-            )
+            Envelope(to=accept.to, sender=accept.sender, message=accept,)
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
         expected_accept = FipaMessage.serializer.decode(envelope.message)
@@ -610,10 +589,7 @@ class TestFIPA(UseOef):
         match_accept.sender = FETCHAI_ADDRESS_ONE
         self.multiplexer1.put(
             Envelope(
-                to=match_accept.to,
-                sender=match_accept.sender,
-                protocol_id=match_accept.protocol_id,
-                message=match_accept,
+                to=match_accept.to, sender=match_accept.sender, message=match_accept,
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
@@ -633,12 +609,7 @@ class TestFIPA(UseOef):
         decline.to = FETCHAI_ADDRESS_TWO
         decline.sender = FETCHAI_ADDRESS_ONE
         self.multiplexer1.put(
-            Envelope(
-                to=decline.to,
-                sender=decline.sender,
-                protocol_id=decline.protocol_id,
-                message=decline,
-            )
+            Envelope(to=decline.to, sender=decline.sender, message=decline,)
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
         expected_decline = FipaMessage.serializer.decode(envelope.message)
@@ -661,7 +632,6 @@ class TestFIPA(UseOef):
             Envelope(
                 to=match_accept_w_inform.to,
                 sender=match_accept_w_inform.sender,
-                protocol_id=match_accept_w_inform.protocol_id,
                 message=match_accept_w_inform,
             )
         )
@@ -686,7 +656,6 @@ class TestFIPA(UseOef):
             Envelope(
                 to=accept_w_inform.to,
                 sender=accept_w_inform.sender,
-                protocol_id=accept_w_inform.protocol_id,
                 message=accept_w_inform,
             )
         )
@@ -709,12 +678,7 @@ class TestFIPA(UseOef):
         inform.to = FETCHAI_ADDRESS_TWO
         inform.sender = FETCHAI_ADDRESS_ONE
         self.multiplexer1.put(
-            Envelope(
-                to=inform.to,
-                sender=inform.sender,
-                protocol_id=inform.protocol_id,
-                message=inform,
-            )
+            Envelope(to=inform.to, sender=inform.sender, message=inform,)
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
         returned_inform = FipaMessage.serializer.decode(envelope.message)
@@ -827,7 +791,7 @@ class TestFIPA(UseOef):
         envelope = Envelope(
             to=str(self.connection1.connection_id),
             sender="me",
-            protocol_id=DefaultMessage.protocol_id,
+            protocol_specification_id=DefaultMessage.protocol_specification_id,
             message=b"Hello",
         )
         self.multiplexer1.put(envelope)
@@ -849,7 +813,7 @@ class TestOefConnection(UseOef):
         connection = _make_oef_connection(
             FETCHAI_ADDRESS_ONE, oef_addr="127.0.0.1", oef_port=10000,
         )
-        multiplexer = Multiplexer([connection])
+        multiplexer = Multiplexer([connection], protocols=[FipaMessage, DefaultMessage])
         multiplexer.connect()
         multiplexer.disconnect()
 
@@ -1010,9 +974,7 @@ class TestSendWithOEF(UseOef):
             )
             msg.to = str(oef_connection.connection_id)
             msg.sender = FETCHAI_ADDRESS_ONE
-            envelope = Envelope(
-                to=msg.to, sender=msg.sender, protocol_id=msg.protocol_id, message=msg,
-            )
+            envelope = Envelope(to=msg.to, sender=msg.sender, message=msg,)
             with caplog.at_level(logging.DEBUG, "aea.packages.fetchai.connections.oef"):
                 await oef_connection.send(envelope)
                 assert "Could not create dialogue for message=" in caplog.text
@@ -1028,9 +990,7 @@ class TestSendWithOEF(UseOef):
                 performative=OefSearchMessage.Performative.SEARCH_SERVICES,
                 query=query,
             )
-            envelope = Envelope(
-                to=msg.to, sender=msg.sender, protocol_id=msg.protocol_id, message=msg,
-            )
+            envelope = Envelope(to=msg.to, sender=msg.sender, message=msg,)
             await oef_connection.send(envelope)
             envelope = await oef_connection.receive()
             search_result = envelope.message
