@@ -17,11 +17,12 @@
 #
 # ------------------------------------------------------------------------------
 
-"""This test module contains tests for P2PLibp2p connection."""
 
+"""This test module contains tests for P2PLibp2p connection."""
 import os
 import shutil
 import tempfile
+from unittest.mock import Mock
 
 import pytest
 
@@ -43,6 +44,12 @@ from tests.conftest import (
 DEFAULT_PORT = 10234
 DEFAULT_NET_SIZE = 4
 
+MockDefaultMessageProtocol = Mock()
+MockDefaultMessageProtocol.protocol_id = DefaultMessage.protocol_id
+MockDefaultMessageProtocol.protocol_specification_id = (
+    DefaultMessage.protocol_specification_id
+)
+
 
 @pytest.mark.asyncio
 class TestP2PLibp2pConnectionConnectDisconnect:
@@ -116,7 +123,9 @@ class TestP2PLibp2pConnectionEchoEnvelope:
             cls.connection1 = _make_libp2p_connection(
                 agent_key=FetchAICrypto(), port=DEFAULT_PORT + 1
             )
-            cls.multiplexer1 = Multiplexer([cls.connection1])
+            cls.multiplexer1 = Multiplexer(
+                [cls.connection1], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection1.node.log_file)
             cls.multiplexer1.connect()
             cls.multiplexers.append(cls.multiplexer1)
@@ -128,7 +137,9 @@ class TestP2PLibp2pConnectionEchoEnvelope:
                 entry_peers=[genesis_peer],
                 agent_key=EthereumCrypto(),
             )
-            cls.multiplexer2 = Multiplexer([cls.connection2])
+            cls.multiplexer2 = Multiplexer(
+                [cls.connection2], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection2.node.log_file)
             cls.multiplexer2.connect()
             cls.multiplexers.append(cls.multiplexer2)
@@ -153,19 +164,17 @@ class TestP2PLibp2pConnectionEchoEnvelope:
             performative=DefaultMessage.Performative.BYTES,
             content=b"hello",
         )
-        envelope = Envelope(
-            to=addr_2,
-            sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
-            message=msg,
-        )
+        envelope = Envelope(to=addr_2, sender=addr_1, message=msg,)
         self.multiplexer1.put(envelope)
         delivered_envelope = self.multiplexer2.get(block=True, timeout=20)
 
         assert delivered_envelope is not None
         assert delivered_envelope.to == envelope.to
         assert delivered_envelope.sender == envelope.sender
-        assert delivered_envelope.protocol_id == envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == envelope.protocol_specification_id
+        )
         assert delivered_envelope.message != envelope.message
         msg = DefaultMessage.serializer.decode(delivered_envelope.message)
         msg.to = delivered_envelope.to
@@ -184,12 +193,7 @@ class TestP2PLibp2pConnectionEchoEnvelope:
             performative=DefaultMessage.Performative.BYTES,
             content=b"hello",
         )
-        original_envelope = Envelope(
-            to=addr_2,
-            sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
-            message=msg,
-        )
+        original_envelope = Envelope(to=addr_2, sender=addr_1, message=msg,)
 
         self.multiplexer1.put(original_envelope)
         delivered_envelope = self.multiplexer2.get(block=True, timeout=10)
@@ -204,7 +208,10 @@ class TestP2PLibp2pConnectionEchoEnvelope:
         assert echoed_envelope is not None
         assert echoed_envelope.to == original_envelope.sender
         assert delivered_envelope.sender == original_envelope.to
-        assert delivered_envelope.protocol_id == original_envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == original_envelope.protocol_specification_id
+        )
         assert delivered_envelope.message != original_envelope.message
         assert original_envelope.message_bytes == delivered_envelope.message_bytes
 
@@ -238,7 +245,9 @@ class TestP2PLibp2pConnectionRouting:
         try:
             port_genesis = DEFAULT_PORT + 10
             cls.connection_genesis = _make_libp2p_connection(port_genesis)
-            cls.multiplexer_genesis = Multiplexer([cls.connection_genesis])
+            cls.multiplexer_genesis = Multiplexer(
+                [cls.connection_genesis], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection_genesis.node.log_file)
             cls.multiplexer_genesis.connect()
             cls.multiplexers.append(cls.multiplexer_genesis)
@@ -251,7 +260,7 @@ class TestP2PLibp2pConnectionRouting:
             for _ in range(DEFAULT_NET_SIZE):
                 port += 1
                 conn = _make_libp2p_connection(port=port, entry_peers=[genesis_peer])
-                mux = Multiplexer([conn])
+                mux = Multiplexer([conn], protocols=[MockDefaultMessageProtocol])
 
                 cls.connections.append(conn)
 
@@ -284,10 +293,7 @@ class TestP2PLibp2pConnectionRouting:
                     content=b"hello",
                 )
                 envelope = Envelope(
-                    to=addrs[destination],
-                    sender=addrs[source],
-                    protocol_id=DefaultMessage.protocol_id,
-                    message=msg,
+                    to=addrs[destination], sender=addrs[source], message=msg,
                 )
 
                 self.multiplexers[source].put(envelope)
@@ -298,7 +304,10 @@ class TestP2PLibp2pConnectionRouting:
                 assert delivered_envelope is not None
                 assert delivered_envelope.to == envelope.to
                 assert delivered_envelope.sender == envelope.sender
-                assert delivered_envelope.protocol_id == envelope.protocol_id
+                assert (
+                    delivered_envelope.protocol_specification_id
+                    == envelope.protocol_specification_id
+                )
                 assert delivered_envelope.message != envelope.message
                 msg = DefaultMessage.serializer.decode(delivered_envelope.message)
                 msg.to = delivered_envelope.to
@@ -344,7 +353,9 @@ class TestP2PLibp2pConnectionEchoEnvelopeRelayOneDHTNode:
             cls.connection1 = _make_libp2p_connection(
                 DEFAULT_PORT + 2, relay=False, entry_peers=[relay_peer]
             )
-            cls.multiplexer1 = Multiplexer([cls.connection1])
+            cls.multiplexer1 = Multiplexer(
+                [cls.connection1], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection1.node.log_file)
             cls.multiplexer1.connect()
             cls.multiplexers.append(cls.multiplexer1)
@@ -352,7 +363,9 @@ class TestP2PLibp2pConnectionEchoEnvelopeRelayOneDHTNode:
             cls.connection2 = _make_libp2p_connection(
                 port=DEFAULT_PORT + 3, entry_peers=[relay_peer]
             )
-            cls.multiplexer2 = Multiplexer([cls.connection2])
+            cls.multiplexer2 = Multiplexer(
+                [cls.connection2], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection2.node.log_file)
             cls.multiplexer2.connect()
             cls.multiplexers.append(cls.multiplexer2)
@@ -378,12 +391,7 @@ class TestP2PLibp2pConnectionEchoEnvelopeRelayOneDHTNode:
             performative=DefaultMessage.Performative.BYTES,
             content=b"hello",
         )
-        envelope = Envelope(
-            to=addr_2,
-            sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
-            message=msg,
-        )
+        envelope = Envelope(to=addr_2, sender=addr_1, message=msg,)
 
         self.multiplexer1.put(envelope)
         delivered_envelope = self.multiplexer2.get(block=True, timeout=20)
@@ -391,7 +399,10 @@ class TestP2PLibp2pConnectionEchoEnvelopeRelayOneDHTNode:
         assert delivered_envelope is not None
         assert delivered_envelope.to == envelope.to
         assert delivered_envelope.sender == envelope.sender
-        assert delivered_envelope.protocol_id == envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == envelope.protocol_specification_id
+        )
         assert delivered_envelope.message != envelope.message
         msg = DefaultMessage.serializer.decode(delivered_envelope.message)
         msg.to = delivered_envelope.to
@@ -410,12 +421,7 @@ class TestP2PLibp2pConnectionEchoEnvelopeRelayOneDHTNode:
             performative=DefaultMessage.Performative.BYTES,
             content=b"hello",
         )
-        original_envelope = Envelope(
-            to=addr_2,
-            sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
-            message=msg,
-        )
+        original_envelope = Envelope(to=addr_2, sender=addr_1, message=msg,)
 
         self.multiplexer1.put(original_envelope)
         delivered_envelope = self.multiplexer2.get(block=True, timeout=10)
@@ -430,7 +436,10 @@ class TestP2PLibp2pConnectionEchoEnvelopeRelayOneDHTNode:
         assert echoed_envelope is not None
         assert echoed_envelope.to == original_envelope.sender
         assert delivered_envelope.sender == original_envelope.to
-        assert delivered_envelope.protocol_id == original_envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == original_envelope.protocol_specification_id
+        )
         assert delivered_envelope.message != original_envelope.message
         assert original_envelope.message_bytes == delivered_envelope.message_bytes
 
@@ -464,7 +473,9 @@ class TestP2PLibp2pConnectionRoutingRelayTwoDHTNodes:
         try:
             port_relay_1 = DEFAULT_PORT + 10
             cls.connection_relay_1 = _make_libp2p_connection(port_relay_1)
-            cls.multiplexer_relay_1 = Multiplexer([cls.connection_relay_1])
+            cls.multiplexer_relay_1 = Multiplexer(
+                [cls.connection_relay_1], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection_relay_1.node.log_file)
             cls.multiplexer_relay_1.connect()
             cls.multiplexers.append(cls.multiplexer_relay_1)
@@ -475,7 +486,9 @@ class TestP2PLibp2pConnectionRoutingRelayTwoDHTNodes:
             cls.connection_relay_2 = _make_libp2p_connection(
                 port=port_relay_2, entry_peers=[relay_peer_1]
             )
-            cls.multiplexer_relay_2 = Multiplexer([cls.connection_relay_2])
+            cls.multiplexer_relay_2 = Multiplexer(
+                [cls.connection_relay_2], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection_relay_2.node.log_file)
             cls.multiplexer_relay_2.connect()
             cls.multiplexers.append(cls.multiplexer_relay_2)
@@ -534,10 +547,7 @@ class TestP2PLibp2pConnectionRoutingRelayTwoDHTNodes:
                     content=b"hello",
                 )
                 envelope = Envelope(
-                    to=addrs[destination],
-                    sender=addrs[source],
-                    protocol_id=DefaultMessage.protocol_id,
-                    message=msg,
+                    to=addrs[destination], sender=addrs[source], message=msg,
                 )
 
                 self.multiplexers[source].put(envelope)
@@ -548,7 +558,10 @@ class TestP2PLibp2pConnectionRoutingRelayTwoDHTNodes:
                 assert delivered_envelope is not None
                 assert delivered_envelope.to == envelope.to
                 assert delivered_envelope.sender == envelope.sender
-                assert delivered_envelope.protocol_id == envelope.protocol_id
+                assert (
+                    delivered_envelope.protocol_specification_id
+                    == envelope.protocol_specification_id
+                )
                 assert delivered_envelope.message != envelope.message
                 msg = DefaultMessage.serializer.decode(delivered_envelope.message)
                 msg.sender = delivered_envelope.sender
