@@ -78,7 +78,7 @@ class TestLibp2pConnectionPublicDHTRelay:
         """Test connectivity."""
         for maddr in PUBLIC_DHT_MADDRS:
             connection = _make_libp2p_connection(
-                DEFAULT_PORT + 1, relay=False, entry_peers=[maddr]
+                DEFAULT_PORT + 1, relay=False, entry_peers=[maddr], data_dir=self.t
             )
             multiplexer = Multiplexer([connection])
             self.log_files.append(connection.node.log_file)
@@ -99,7 +99,7 @@ class TestLibp2pConnectionPublicDHTRelay:
             multiplexers = []
             try:
                 connection1 = _make_libp2p_connection(
-                    DEFAULT_PORT + 1, relay=False, entry_peers=[maddr]
+                    DEFAULT_PORT + 1, relay=False, entry_peers=[maddr], data_dir=self.t
                 )
                 multiplexer1 = Multiplexer([connection1])
                 self.log_files.append(connection1.node.log_file)
@@ -107,7 +107,7 @@ class TestLibp2pConnectionPublicDHTRelay:
                 multiplexers.append(multiplexer1)
 
                 connection2 = _make_libp2p_connection(
-                    DEFAULT_PORT + 2, relay=False, entry_peers=[maddr]
+                    DEFAULT_PORT + 2, relay=False, entry_peers=[maddr], data_dir=self.t
                 )
                 multiplexer2 = Multiplexer([connection2])
                 self.log_files.append(connection2.node.log_file)
@@ -124,12 +124,7 @@ class TestLibp2pConnectionPublicDHTRelay:
                     performative=DefaultMessage.Performative.BYTES,
                     content=b"hello",
                 )
-                envelope = Envelope(
-                    to=addr_2,
-                    sender=addr_1,
-                    protocol_id=DefaultMessage.protocol_id,
-                    message=msg,
-                )
+                envelope = Envelope(to=addr_2, sender=addr_1, message=msg,)
 
                 multiplexer1.put(envelope)
                 delivered_envelope = multiplexer2.get(block=True, timeout=20)
@@ -137,7 +132,10 @@ class TestLibp2pConnectionPublicDHTRelay:
                 assert delivered_envelope is not None
                 assert delivered_envelope.to == envelope.to
                 assert delivered_envelope.sender == envelope.sender
-                assert delivered_envelope.protocol_id == envelope.protocol_id
+                assert (
+                    delivered_envelope.protocol_specification_id
+                    == envelope.protocol_specification_id
+                )
                 assert delivered_envelope.message != envelope.message
                 msg = DefaultMessage.serializer.decode(delivered_envelope.message)
                 msg.to = delivered_envelope.to
@@ -157,7 +155,10 @@ class TestLibp2pConnectionPublicDHTRelay:
             multiplexers = []
             try:
                 connection1 = _make_libp2p_connection(
-                    DEFAULT_PORT + 1, relay=False, entry_peers=[PUBLIC_DHT_MADDRS[i]]
+                    DEFAULT_PORT + 1,
+                    relay=False,
+                    entry_peers=[PUBLIC_DHT_MADDRS[i]],
+                    data_dir=self.t,
                 )
                 multiplexer1 = Multiplexer([connection1])
                 self.log_files.append(connection1.node.log_file)
@@ -173,6 +174,7 @@ class TestLibp2pConnectionPublicDHTRelay:
                         DEFAULT_PORT + 2,
                         relay=False,
                         entry_peers=[PUBLIC_DHT_MADDRS[j]],
+                        data_dir=self.t,
                     )
                     multiplexer2 = Multiplexer([connection2])
                     self.log_files.append(connection2.node.log_file)
@@ -188,12 +190,7 @@ class TestLibp2pConnectionPublicDHTRelay:
                         performative=DefaultMessage.Performative.BYTES,
                         content=b"hello",
                     )
-                    envelope = Envelope(
-                        to=addr_2,
-                        sender=addr_1,
-                        protocol_id=DefaultMessage.protocol_id,
-                        message=msg,
-                    )
+                    envelope = Envelope(to=addr_2, sender=addr_1, message=msg,)
 
                     multiplexer1.put(envelope)
                     delivered_envelope = multiplexer2.get(block=True, timeout=20)
@@ -201,7 +198,10 @@ class TestLibp2pConnectionPublicDHTRelay:
                     assert delivered_envelope is not None
                     assert delivered_envelope.to == envelope.to
                     assert delivered_envelope.sender == envelope.sender
-                    assert delivered_envelope.protocol_id == envelope.protocol_id
+                    assert (
+                        delivered_envelope.protocol_specification_id
+                        == envelope.protocol_specification_id
+                    )
                     assert delivered_envelope.message != envelope.message
                     msg = DefaultMessage.serializer.decode(delivered_envelope.message)
                     msg.to = delivered_envelope.to
@@ -229,12 +229,20 @@ class TestLibp2pConnectionPublicDHTRelay:
 class TestLibp2pConnectionPublicDHTDelegate:
     """Test that public DHT's delegate service is working properly"""
 
+    def setup(self):
+        """Set the test up"""
+        self.cwd = os.getcwd()
+        self.t = tempfile.mkdtemp()
+        os.chdir(self.t)
+
     def test_connectivity(self):
         """Test connectivity."""
         for i in range(len(PUBLIC_DHT_DELEGATE_URIS)):
             uri = PUBLIC_DHT_DELEGATE_URIS[i]
             peer_public_key = PUBLIC_DHT_PUBLIC_KEYS[i]
-            connection = _make_libp2p_client_connection(peer_public_key, uri=uri)
+            connection = _make_libp2p_client_connection(
+                peer_public_key, uri=uri, data_dir=self.t
+            )
             multiplexer = Multiplexer([connection])
 
             try:
@@ -254,12 +262,16 @@ class TestLibp2pConnectionPublicDHTDelegate:
             peer_public_key = PUBLIC_DHT_PUBLIC_KEYS[i]
             multiplexers = []
             try:
-                connection1 = _make_libp2p_client_connection(peer_public_key, uri=uri)
+                connection1 = _make_libp2p_client_connection(
+                    peer_public_key, uri=uri, data_dir=self.t
+                )
                 multiplexer1 = Multiplexer([connection1])
                 multiplexer1.connect()
                 multiplexers.append(multiplexer1)
 
-                connection2 = _make_libp2p_client_connection(peer_public_key, uri=uri)
+                connection2 = _make_libp2p_client_connection(
+                    peer_public_key, uri=uri, data_dir=self.t
+                )
                 multiplexer2 = Multiplexer([connection2])
                 multiplexer2.connect()
                 multiplexers.append(multiplexer2)
@@ -274,12 +286,7 @@ class TestLibp2pConnectionPublicDHTDelegate:
                     performative=DefaultMessage.Performative.BYTES,
                     content=b"hello",
                 )
-                envelope = Envelope(
-                    to=addr_2,
-                    sender=addr_1,
-                    protocol_id=DefaultMessage.protocol_id,
-                    message=msg,
-                )
+                envelope = Envelope(to=addr_2, sender=addr_1, message=msg,)
 
                 multiplexer1.put(envelope)
                 delivered_envelope = multiplexer2.get(block=True, timeout=20)
@@ -287,7 +294,10 @@ class TestLibp2pConnectionPublicDHTDelegate:
                 assert delivered_envelope is not None
                 assert delivered_envelope.to == envelope.to
                 assert delivered_envelope.sender == envelope.sender
-                assert delivered_envelope.protocol_id == envelope.protocol_id
+                assert (
+                    delivered_envelope.protocol_specification_id
+                    == envelope.protocol_specification_id
+                )
                 assert delivered_envelope.message != envelope.message
                 msg = DefaultMessage.serializer.decode(delivered_envelope.message)
                 msg.to = delivered_envelope.to
@@ -309,7 +319,9 @@ class TestLibp2pConnectionPublicDHTDelegate:
             multiplexers = []
             try:
                 connection1 = _make_libp2p_client_connection(
-                    PUBLIC_DHT_PUBLIC_KEYS[i], uri=PUBLIC_DHT_DELEGATE_URIS[i]
+                    PUBLIC_DHT_PUBLIC_KEYS[i],
+                    uri=PUBLIC_DHT_DELEGATE_URIS[i],
+                    data_dir=self.t,
                 )
                 multiplexer1 = Multiplexer([connection1])
                 multiplexer1.connect()
@@ -322,7 +334,9 @@ class TestLibp2pConnectionPublicDHTDelegate:
                         continue
 
                     connection2 = _make_libp2p_client_connection(
-                        PUBLIC_DHT_PUBLIC_KEYS[j], uri=PUBLIC_DHT_DELEGATE_URIS[j]
+                        PUBLIC_DHT_PUBLIC_KEYS[j],
+                        uri=PUBLIC_DHT_DELEGATE_URIS[j],
+                        data_dir=self.t,
                     )
                     multiplexer2 = Multiplexer([connection2])
                     multiplexer2.connect()
@@ -336,12 +350,7 @@ class TestLibp2pConnectionPublicDHTDelegate:
                         performative=DefaultMessage.Performative.BYTES,
                         content=b"hello",
                     )
-                    envelope = Envelope(
-                        to=addr_2,
-                        sender=addr_1,
-                        protocol_id=DefaultMessage.protocol_id,
-                        message=msg,
-                    )
+                    envelope = Envelope(to=addr_2, sender=addr_1, message=msg,)
 
                     multiplexer1.put(envelope)
                     delivered_envelope = multiplexer2.get(block=True, timeout=20)
@@ -349,7 +358,10 @@ class TestLibp2pConnectionPublicDHTDelegate:
                     assert delivered_envelope is not None
                     assert delivered_envelope.to == envelope.to
                     assert delivered_envelope.sender == envelope.sender
-                    assert delivered_envelope.protocol_id == envelope.protocol_id
+                    assert (
+                        delivered_envelope.protocol_specification_id
+                        == envelope.protocol_specification_id
+                    )
                     assert delivered_envelope.message != envelope.message
                     msg = DefaultMessage.serializer.decode(delivered_envelope.message)
                     msg.to = delivered_envelope.to
@@ -363,6 +375,14 @@ class TestLibp2pConnectionPublicDHTDelegate:
                 for mux in multiplexers:
                     mux.disconnect()
 
+    def teardown(self):
+        """Tear down the test"""
+        os.chdir(self.cwd)
+        try:
+            shutil.rmtree(self.t)
+        except (OSError, IOError):
+            pass
+
 
 @pytest.mark.integration
 class TestLibp2pConnectionPublicDHTRelayAEACli(AEATestCaseEmpty):
