@@ -17,11 +17,12 @@
 #
 # ------------------------------------------------------------------------------
 
-"""This test module contains tests for Libp2p tcp client connection."""
 
+"""This test module contains tests for Libp2p tcp client connection."""
 import os
 import shutil
 import tempfile
+from unittest.mock import Mock
 
 import pytest
 
@@ -47,6 +48,12 @@ DEFAULT_DELEGATE_PORT = 11234
 DEFAULT_HOST = "127.0.0.1"
 DEFAULT_CLIENTS_PER_NODE = 4
 
+MockDefaultMessageProtocol = Mock()
+MockDefaultMessageProtocol.protocol_id = DefaultMessage.protocol_id
+MockDefaultMessageProtocol.protocol_specification_id = (
+    DefaultMessage.protocol_specification_id
+)
+
 
 @pytest.mark.asyncio
 class TestLibp2pClientConnectionConnectDisconnect:
@@ -103,7 +110,9 @@ class TestLibp2pClientConnectionEchoEnvelope:
         cls.log_files = []
 
         cls.connection_node = _make_libp2p_connection(DEFAULT_PORT + 1, delegate=True)
-        cls.multiplexer_node = Multiplexer([cls.connection_node])
+        cls.multiplexer_node = Multiplexer(
+            [cls.connection_node], protocols=[MockDefaultMessageProtocol]
+        )
         cls.log_files.append(cls.connection_node.node.log_file)
         cls.multiplexer_node.connect()
 
@@ -112,14 +121,18 @@ class TestLibp2pClientConnectionEchoEnvelope:
                 peer_public_key=cls.connection_node.node.pub,
                 ledger_api_id=FetchAICrypto.identifier,
             )
-            cls.multiplexer_client_1 = Multiplexer([cls.connection_client_1])
+            cls.multiplexer_client_1 = Multiplexer(
+                [cls.connection_client_1], protocols=[MockDefaultMessageProtocol]
+            )
             cls.multiplexer_client_1.connect()
 
             cls.connection_client_2 = _make_libp2p_client_connection(
                 peer_public_key=cls.connection_node.node.pub,
                 ledger_api_id=EthereumCrypto.identifier,
             )
-            cls.multiplexer_client_2 = Multiplexer([cls.connection_client_2])
+            cls.multiplexer_client_2 = Multiplexer(
+                [cls.connection_client_2], protocols=[MockDefaultMessageProtocol]
+            )
             cls.multiplexer_client_2.connect()
         except Exception:
             cls.multiplexer_node.disconnect()
@@ -145,7 +158,7 @@ class TestLibp2pClientConnectionEchoEnvelope:
         envelope = Envelope(
             to=addr_2,
             sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
+            protocol_specification_id=DefaultMessage.protocol_specification_id,
             message=DefaultSerializer().encode(msg),
         )
 
@@ -155,7 +168,10 @@ class TestLibp2pClientConnectionEchoEnvelope:
         assert delivered_envelope is not None
         assert delivered_envelope.to == envelope.to
         assert delivered_envelope.sender == envelope.sender
-        assert delivered_envelope.protocol_id == envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == envelope.protocol_specification_id
+        )
         assert delivered_envelope.message == envelope.message
 
     def test_envelope_echoed_back(self):
@@ -173,7 +189,7 @@ class TestLibp2pClientConnectionEchoEnvelope:
         original_envelope = Envelope(
             to=addr_2,
             sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
+            protocol_specification_id=DefaultMessage.protocol_specification_id,
             message=DefaultSerializer().encode(msg),
         )
 
@@ -190,7 +206,10 @@ class TestLibp2pClientConnectionEchoEnvelope:
         assert echoed_envelope is not None
         assert echoed_envelope.to == original_envelope.sender
         assert delivered_envelope.sender == original_envelope.to
-        assert delivered_envelope.protocol_id == original_envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == original_envelope.protocol_specification_id
+        )
         assert delivered_envelope.message == original_envelope.message
 
     def test_envelope_echoed_back_node_agent(self):
@@ -208,7 +227,7 @@ class TestLibp2pClientConnectionEchoEnvelope:
         original_envelope = Envelope(
             to=addr_n,
             sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
+            protocol_specification_id=DefaultMessage.protocol_specification_id,
             message=DefaultSerializer().encode(msg),
         )
 
@@ -225,7 +244,10 @@ class TestLibp2pClientConnectionEchoEnvelope:
         assert echoed_envelope is not None
         assert echoed_envelope.to == original_envelope.sender
         assert delivered_envelope.sender == original_envelope.to
-        assert delivered_envelope.protocol_id == original_envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == original_envelope.protocol_specification_id
+        )
         assert delivered_envelope.message == original_envelope.message
 
     @classmethod
@@ -262,7 +284,9 @@ class TestLibp2pClientConnectionEchoEnvelopeTwoDHTNode:
             delegate_port=DEFAULT_DELEGATE_PORT + 1,
             delegate=True,
         )
-        cls.multiplexer_node_1 = Multiplexer([cls.connection_node_1])
+        cls.multiplexer_node_1 = Multiplexer(
+            [cls.connection_node_1], protocols=[MockDefaultMessageProtocol]
+        )
         cls.log_files.append(cls.connection_node_1.node.log_file)
         cls.multiplexer_node_1.connect()
         cls.mutliplexers.append(cls.multiplexer_node_1)
@@ -276,7 +300,9 @@ class TestLibp2pClientConnectionEchoEnvelopeTwoDHTNode:
                 entry_peers=[genesis_peer],
                 delegate=True,
             )
-            cls.multiplexer_node_2 = Multiplexer([cls.connection_node_2])
+            cls.multiplexer_node_2 = Multiplexer(
+                [cls.connection_node_2], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection_node_2.node.log_file)
             cls.multiplexer_node_2.connect()
             cls.mutliplexers.append(cls.multiplexer_node_2)
@@ -284,14 +310,18 @@ class TestLibp2pClientConnectionEchoEnvelopeTwoDHTNode:
             cls.connection_client_1 = _make_libp2p_client_connection(
                 cls.connection_node_1.node.pub, DEFAULT_DELEGATE_PORT + 1
             )
-            cls.multiplexer_client_1 = Multiplexer([cls.connection_client_1])
+            cls.multiplexer_client_1 = Multiplexer(
+                [cls.connection_client_1], protocols=[MockDefaultMessageProtocol]
+            )
             cls.multiplexer_client_1.connect()
             cls.mutliplexers.append(cls.multiplexer_client_1)
 
             cls.connection_client_2 = _make_libp2p_client_connection(
                 cls.connection_node_2.node.pub, DEFAULT_DELEGATE_PORT + 2
             )
-            cls.multiplexer_client_2 = Multiplexer([cls.connection_client_2])
+            cls.multiplexer_client_2 = Multiplexer(
+                [cls.connection_client_2], protocols=[MockDefaultMessageProtocol]
+            )
             cls.multiplexer_client_2.connect()
             cls.mutliplexers.append(cls.multiplexer_client_2)
         except Exception:
@@ -320,7 +350,7 @@ class TestLibp2pClientConnectionEchoEnvelopeTwoDHTNode:
         envelope = Envelope(
             to=addr_2,
             sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
+            protocol_specification_id=DefaultMessage.protocol_specification_id,
             message=DefaultSerializer().encode(msg),
         )
 
@@ -330,7 +360,10 @@ class TestLibp2pClientConnectionEchoEnvelopeTwoDHTNode:
         assert delivered_envelope is not None
         assert delivered_envelope.to == envelope.to
         assert delivered_envelope.sender == envelope.sender
-        assert delivered_envelope.protocol_id == envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == envelope.protocol_specification_id
+        )
         assert delivered_envelope.message == envelope.message
 
     def test_envelope_echoed_back(self):
@@ -348,7 +381,7 @@ class TestLibp2pClientConnectionEchoEnvelopeTwoDHTNode:
         original_envelope = Envelope(
             to=addr_2,
             sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
+            protocol_specification_id=DefaultMessage.protocol_specification_id,
             message=DefaultSerializer().encode(msg),
         )
 
@@ -365,7 +398,10 @@ class TestLibp2pClientConnectionEchoEnvelopeTwoDHTNode:
         assert echoed_envelope is not None
         assert echoed_envelope.to == original_envelope.sender
         assert delivered_envelope.sender == original_envelope.to
-        assert delivered_envelope.protocol_id == original_envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == original_envelope.protocol_specification_id
+        )
         assert delivered_envelope.message == original_envelope.message
 
     def test_envelope_echoed_back_node_agent(self):
@@ -383,7 +419,7 @@ class TestLibp2pClientConnectionEchoEnvelopeTwoDHTNode:
         original_envelope = Envelope(
             to=addr_n,
             sender=addr_1,
-            protocol_id=DefaultMessage.protocol_id,
+            protocol_specification_id=DefaultMessage.protocol_specification_id,
             message=DefaultSerializer().encode(msg),
         )
 
@@ -400,7 +436,10 @@ class TestLibp2pClientConnectionEchoEnvelopeTwoDHTNode:
         assert echoed_envelope is not None
         assert echoed_envelope.to == original_envelope.sender
         assert delivered_envelope.sender == original_envelope.to
-        assert delivered_envelope.protocol_id == original_envelope.protocol_id
+        assert (
+            delivered_envelope.protocol_specification_id
+            == original_envelope.protocol_specification_id
+        )
         assert delivered_envelope.message == original_envelope.message
 
     @classmethod
@@ -436,7 +475,9 @@ class TestLibp2pClientConnectionRouting:
                 delegate_port=DEFAULT_DELEGATE_PORT + 1,
                 delegate=True,
             )
-            cls.multiplexer_node_1 = Multiplexer([cls.connection_node_1])
+            cls.multiplexer_node_1 = Multiplexer(
+                [cls.connection_node_1], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection_node_1.node.log_file)
             cls.multiplexer_node_1.connect()
             cls.multiplexers.append(cls.multiplexer_node_1)
@@ -449,7 +490,9 @@ class TestLibp2pClientConnectionRouting:
                 entry_peers=[entry_peer],
                 delegate=True,
             )
-            cls.multiplexer_node_2 = Multiplexer([cls.connection_node_2])
+            cls.multiplexer_node_2 = Multiplexer(
+                [cls.connection_node_2], protocols=[MockDefaultMessageProtocol]
+            )
             cls.log_files.append(cls.connection_node_2.node.log_file)
             cls.multiplexer_node_2.connect()
             cls.multiplexers.append(cls.multiplexer_node_2)
@@ -470,7 +513,7 @@ class TestLibp2pClientConnectionRouting:
                     port = ports[i]
                     peer_public_key = peers_public_keys[i]
                     conn = _make_libp2p_client_connection(peer_public_key, port)
-                    mux = Multiplexer([conn])
+                    mux = Multiplexer([conn], protocols=[MockDefaultMessageProtocol])
 
                     cls.connections.append(conn)
                     cls.addresses.append(conn.address)
@@ -503,7 +546,7 @@ class TestLibp2pClientConnectionRouting:
                 envelope = Envelope(
                     to=self.addresses[destination],
                     sender=self.addresses[source],
-                    protocol_id=DefaultMessage.protocol_id,
+                    protocol_specification_id=DefaultMessage.protocol_specification_id,
                     message=DefaultSerializer().encode(msg),
                 )
 
@@ -515,7 +558,10 @@ class TestLibp2pClientConnectionRouting:
                 assert delivered_envelope is not None
                 assert delivered_envelope.to == envelope.to
                 assert delivered_envelope.sender == envelope.sender
-                assert delivered_envelope.protocol_id == envelope.protocol_id
+                assert (
+                    delivered_envelope.protocol_specification_id
+                    == envelope.protocol_specification_id
+                )
                 assert delivered_envelope.message == envelope.message
 
     @classmethod
