@@ -17,9 +17,11 @@
 #
 # ------------------------------------------------------------------------------
 """This module contains the tests of the soef connection module."""
-
 import asyncio
 import os
+import shutil
+import tempfile
+from pathlib import Path
 from typing import Any, Callable
 from unittest.mock import MagicMock, patch
 
@@ -29,6 +31,7 @@ from aea.common import Address
 from aea.configurations.base import ConnectionConfig
 from aea.configurations.constants import DEFAULT_LEDGER
 from aea.crypto.registries import make_crypto
+from aea.exceptions import AEAEnforceError
 from aea.helpers.search.models import (
     Attribute,
     Constraint,
@@ -106,6 +109,7 @@ class TestSoefTokenStorage:
         """Set up."""
         self.crypto = make_crypto(DEFAULT_LEDGER)
         self.crypto2 = make_crypto(DEFAULT_LEDGER)
+        self.data_dir = tempfile.mkdtemp()
         identity = Identity("", address=self.crypto.address)
         self.oef_search_dialogues = OefSearchDialogues(self.crypto.address)
 
@@ -116,17 +120,18 @@ class TestSoefTokenStorage:
             soef_addr="soef.fetch.ai",
             soef_port=9002,
             token_storage_path=self.token_storage_path,
-            restricted_to_protocols={OefSearchMessage.protocol_id},
+            restricted_to_protocols={OefSearchMessage.protocol_specification_id},
             connection_id=SOEFConnection.connection_id,
         )
         self.connection = SOEFConnection(
-            configuration=configuration, identity=identity,
+            configuration=configuration, data_dir=self.data_dir, identity=identity,
         )
 
     def teardown(self):
         """Tear down."""
         try:
             os.remove(self.token_storage_path)
+            shutil.rmtree(self.data_dir)
         except Exception as e:
             print(e)
 
@@ -145,13 +150,14 @@ class TestSoefTokenStorage:
         self.connection.channel.unique_page_address = "test"
         assert self.connection.channel._unique_page_address == "test"
         assert self.connection.channel.unique_page_address == "test"
-        with open(self.token_storage_path, "r") as f:
+        expected_token_storage_path = Path(self.data_dir) / self.token_storage_path
+        with expected_token_storage_path.open() as f:
             in_file = f.read()
         assert in_file == "test"
         self.connection.channel.unique_page_address = None
         assert self.connection.channel._unique_page_address is None
         assert self.connection.channel.unique_page_address is None
-        with open(self.token_storage_path, "r") as f:
+        with expected_token_storage_path.open() as f:
             in_file = f.read()
         assert in_file == self.connection.channel.NONE_UNIQUE_PAGE_ADDRESS
 
@@ -172,20 +178,22 @@ class TestSoef:
         self.crypto2 = make_crypto(DEFAULT_LEDGER)
         identity = Identity("", address=self.crypto.address)
         self.oef_search_dialogues = OefSearchDialogues(self.crypto.address)
+        self.data_dir = tempfile.mkdtemp()
 
         # create the connection and multiplexer objects
         configuration = ConnectionConfig(
             api_key="TwiCIriSl0mLahw17pyqoA",
             soef_addr="soef.fetch.ai",
             soef_port=9002,
-            restricted_to_protocols={OefSearchMessage.protocol_id},
+            restricted_to_protocols={OefSearchMessage.protocol_specification_id},
             connection_id=SOEFConnection.connection_id,
         )
         self.connection = SOEFConnection(
-            configuration=configuration, identity=identity,
+            configuration=configuration, data_dir=self.data_dir, identity=identity,
         )
         self.connection2 = SOEFConnection(
             configuration=configuration,
+            data_dir=self.data_dir,
             identity=Identity("", address=self.crypto2.address),
         )
         self.loop = asyncio.get_event_loop()
@@ -205,12 +213,7 @@ class TestSoef:
             performative=OefSearchMessage.Performative.REGISTER_SERVICE,
             service_description=service_description,
         )
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
 
         with patch.object(
             self.connection.channel,
@@ -235,12 +238,7 @@ class TestSoef:
             performative=OefSearchMessage.Performative.UNREGISTER_SERVICE,
             service_description=service_description,
         )
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
 
         with patch.object(
             self.connection.channel,
@@ -281,12 +279,7 @@ class TestSoef:
             performative=OefSearchMessage.Performative.REGISTER_SERVICE,
             service_description=service_description,
         )
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
 
         with patch.object(
             self.connection.channel,
@@ -322,12 +315,7 @@ class TestSoef:
             performative=OefSearchMessage.Performative.REGISTER_SERVICE,
             service_description=service_description,
         )
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
         await self.connection.send(envelope)
 
         expected_envelope = await asyncio.wait_for(self.connection.receive(), timeout=1)
@@ -353,12 +341,7 @@ class TestSoef:
             performative=OefSearchMessage.Performative.UNREGISTER_SERVICE,
             service_description=service_description,
         )
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
         with patch.object(
             self.connection.channel,
             "_request_text",
@@ -380,12 +363,7 @@ class TestSoef:
             performative=OefSearchMessage.Performative.REGISTER_SERVICE,
             service_description=service_description,
         )
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
         with patch.object(
             self.connection.channel,
             "_request_text",
@@ -396,31 +374,18 @@ class TestSoef:
         with pytest.raises(asyncio.TimeoutError):  # got no message back
             await asyncio.wait_for(self.connection.receive(), timeout=1)
 
-    @pytest.mark.asyncio
-    async def test_send_excluded_protocol(self):
-        """Test fail on unsupported protocol."""
-        envelope = Envelope(
-            to="soef",
-            sender=self.crypto.address,
-            protocol_id=UNKNOWN_PROTOCOL_PUBLIC_ID,
-            message=b"some msg",
-        )
-        self.connection.channel.excluded_protocols = [UNKNOWN_PROTOCOL_PUBLIC_ID]
-        with pytest.raises(
-            ValueError, match=r"Cannot send message, invalid protocol:.*"
-        ):
-            await self.connection.send(envelope)
-
     @pytest.mark.asyncio
     async def test_bad_message(self):
         """Test fail on bad message."""
         envelope = Envelope(
             to="soef",
             sender=self.crypto.address,
-            protocol_id=UNKNOWN_PROTOCOL_PUBLIC_ID,
+            protocol_specification_id=UNKNOWN_PROTOCOL_PUBLIC_ID,
             message=b"some msg",
         )
-        with pytest.raises(ValueError):
+        with pytest.raises(
+            AEAEnforceError, match=r"Message not of type OefSearchMessage"
+        ):
             await self.connection.send(envelope)
 
     @pytest.mark.asyncio
@@ -438,12 +403,7 @@ class TestSoef:
         )
         message.to = str(SOEFConnection.connection_id.to_any())
         message.sender = self.crypto.address
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
         with pytest.raises(ValueError):
             await self.connection.send(envelope)
 
@@ -457,12 +417,7 @@ class TestSoef:
             performative=OefSearchMessage.Performative.SEARCH_SERVICES,
             query=closeness_query,
         )
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
 
         with patch.object(
             self.connection.channel,
@@ -504,12 +459,7 @@ class TestSoef:
             performative=OefSearchMessage.Performative.SEARCH_SERVICES,
             query=closeness_query,
         )
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
 
         with patch.object(
             self.connection.channel,
@@ -644,7 +594,7 @@ class TestSoef:
     @pytest.mark.asyncio
     async def test_request(self):
         """Test internal method request_text."""
-        with patch("requests.request"):
+        with patch("aea.helpers.http_requests.request"):
             await self.connection.channel._request_text("get", "http://not-exists.com")
 
     @pytest.mark.asyncio
@@ -691,6 +641,7 @@ class TestSoef:
                 make_async("<response><message>Goodbye!</message></response>"),
             ):
                 self.loop.run_until_complete(self.connection.disconnect())
+                shutil.rmtree(self.data_dir)
         except Exception:  # nosec
             pass
 
@@ -719,13 +670,13 @@ class TestSoef:
             api_key="TwiCIriSl0mLahw17pyqoA",
             soef_addr="soef.fetch.ai",
             soef_port=9002,
-            restricted_to_protocols={OefSearchMessage.protocol_id},
+            restricted_to_protocols={OefSearchMessage.protocol_specification_id},
             connection_id=SOEFConnection.connection_id,
             chain_identifier=chain_identifier,
         )
         with pytest.raises(ValueError, match="Unsupported chain_identifier"):
             SOEFConnection(
-                configuration=configuration, identity=identity,
+                configuration=configuration, data_dir=MagicMock(), identity=identity,
             )
 
     def test_chain_identifier_ok(self):
@@ -737,11 +688,13 @@ class TestSoef:
             api_key="TwiCIriSl0mLahw17pyqoA",
             soef_addr="soef.fetch.ai",
             soef_port=9002,
-            restricted_to_protocols={OefSearchMessage.protocol_id},
+            restricted_to_protocols={OefSearchMessage.protocol_specification_id},
             connection_id=SOEFConnection.connection_id,
             chain_identifier=chain_identifier,
         )
-        connection = SOEFConnection(configuration=configuration, identity=identity,)
+        connection = SOEFConnection(
+            configuration=configuration, data_dir=MagicMock(), identity=identity,
+        )
 
         assert connection.channel.chain_identifier == chain_identifier
 
@@ -754,12 +707,7 @@ class TestSoef:
             performative=OefSearchMessage.Performative.REGISTER_SERVICE,
             service_description=service_description,
         )
-        envelope = Envelope(
-            to=message.to,
-            sender=message.sender,
-            protocol_id=message.protocol_id,
-            message=message,
-        )
+        envelope = Envelope(to=message.to, sender=message.sender, message=message,)
 
         with patch.object(
             self.connection.channel,
