@@ -25,6 +25,7 @@ import tempfile
 import time
 from pathlib import Path
 from unittest import mock
+from unittest.mock import MagicMock
 
 import pytest
 
@@ -60,9 +61,7 @@ def make_test_envelope() -> Envelope:
         content=b"hello",
     )
     msg.to = "any"
-    envelope = Envelope(
-        to="any", sender="any", protocol_id=DefaultMessage.protocol_id, message=msg,
-    )
+    envelope = Envelope(to="any", sender="any", message=msg,)
     return envelope
 
 
@@ -94,12 +93,7 @@ class TestStubConnectionReception:
             performative=DefaultMessage.Performative.BYTES,
             content=b"hello",
         )
-        expected_envelope = Envelope(
-            to="any",
-            sender="anys",
-            protocol_id=DefaultMessage.protocol_id,
-            message=msg,
-        )
+        expected_envelope = Envelope(to="any", sender="anys", message=msg,)
 
         with open(self.input_file_path, "ab+") as f:
             write_envelope(expected_envelope, f)
@@ -107,7 +101,10 @@ class TestStubConnectionReception:
         actual_envelope = self.multiplexer.get(block=True, timeout=3.0)
         assert expected_envelope.to == actual_envelope.to
         assert expected_envelope.sender == actual_envelope.sender
-        assert expected_envelope.protocol_id == actual_envelope.protocol_id
+        assert (
+            expected_envelope.protocol_specification_id
+            == actual_envelope.protocol_specification_id
+        )
         msg = DefaultMessage.serializer.decode(actual_envelope.message)
         msg.to = actual_envelope.to
         msg.sender = actual_envelope.sender
@@ -117,13 +114,13 @@ class TestStubConnectionReception:
         """Test that the connection receives what has been enqueued in the input file."""
         # a message containing delimiters and newline characters
         msg = b"\x08\x02\x12\x011\x1a\x011 \x01:,\n*0x32468d\n,\nB8Ab795\n\n49B49C88DC991990E7910891,,dbd\n"
-        protocol_id = PublicId.from_str("some_author/some_name:0.1.0")
+        protocol_specification_id = PublicId.from_str("some_author/some_name:0.1.0")
         encoded_envelope = "{}{}{}{}{}{}{}{}".format(
             "any",
             SEPARATOR,
             "any",
             SEPARATOR,
-            protocol_id,
+            protocol_specification_id,
             SEPARATOR,
             msg.decode("utf-8"),
             SEPARATOR,
@@ -136,16 +133,16 @@ class TestStubConnectionReception:
         actual_envelope = self.multiplexer.get(block=True, timeout=3.0)
         assert "any" == actual_envelope.to
         assert "any" == actual_envelope.sender
-        assert protocol_id == actual_envelope.protocol_id
+        assert protocol_specification_id == actual_envelope.protocol_specification_id
         assert msg == actual_envelope.message
 
     def test_reception_c(self):
         """Test that the connection receives what has been enqueued in the input file."""
-        encoded_envelope = b"0x5E22777dD831A459535AA4306AceC9cb22eC4cB5,default_oef,fetchai/oef_search:0.12.0,\x08\x02\x12\x011\x1a\x011 \x01:,\n*0x32468dB8Ab79549B49C88DC991990E7910891dbd,"
+        encoded_envelope = b"0x5E22777dD831A459535AA4306AceC9cb22eC4cB5,default_oef,fetchai/oef_search:0.1.0,\x08\x02\x12\x011\x1a\x011 \x01:,\n*0x32468dB8Ab79549B49C88DC991990E7910891dbd,"
         expected_envelope = Envelope(
             to="0x5E22777dD831A459535AA4306AceC9cb22eC4cB5",
             sender="default_oef",
-            protocol_id=OefSearchMessage.protocol_id,
+            protocol_specification_id=OefSearchMessage.protocol_specification_id,
             message=b"\x08\x02\x12\x011\x1a\x011 \x01:,\n*0x32468dB8Ab79549B49C88DC991990E7910891dbd",
         )
         with open(self.input_file_path, "ab+") as f:
@@ -199,7 +196,7 @@ class TestStubConnectionSending:
             SEPARATOR,
             "any",
             SEPARATOR,
-            DefaultMessage.protocol_id,
+            DefaultMessage.protocol_specification_id,
             SEPARATOR,
             DefaultMessage.serializer.encode(msg).decode("utf-8"),
             SEPARATOR,
@@ -222,12 +219,7 @@ class TestStubConnectionSending:
             performative=DefaultMessage.Performative.BYTES,
             content=b"hello",
         )
-        expected_envelope = Envelope(
-            to="any",
-            sender="anys",
-            protocol_id=DefaultMessage.protocol_id,
-            message=msg,
-        )
+        expected_envelope = Envelope(to="any", sender="anys", message=msg,)
 
         self.multiplexer.put(expected_envelope)
         time.sleep(0.1)
@@ -237,20 +229,28 @@ class TestStubConnectionSending:
 
         assert len(lines) == 2
         line = lines[0] + lines[1]
-        to, sender, protocol_id, message, end = line.strip().split(
+        to, sender, protocol_specification_id, message, end = line.strip().split(
             "{}".format(SEPARATOR).encode("utf-8"), maxsplit=4
         )
         to = to.decode("utf-8")
         sender = sender.decode("utf-8")
-        protocol_id = PublicId.from_str(protocol_id.decode("utf-8"))
+        protocol_specification_id = PublicId.from_str(
+            protocol_specification_id.decode("utf-8")
+        )
         assert end in [b"", b"\n"]
 
         actual_envelope = Envelope(
-            to=to, sender=sender, protocol_id=protocol_id, message=message
+            to=to,
+            sender=sender,
+            protocol_specification_id=protocol_specification_id,
+            message=message,
         )
         assert expected_envelope.to == actual_envelope.to
         assert expected_envelope.sender == actual_envelope.sender
-        assert expected_envelope.protocol_id == actual_envelope.protocol_id
+        assert (
+            expected_envelope.protocol_specification_id
+            == actual_envelope.protocol_specification_id
+        )
         msg = DefaultMessage.serializer.decode(actual_envelope.message)
         msg.to = actual_envelope.to
         msg.sender = actual_envelope.sender
@@ -377,6 +377,7 @@ async def test_load_from_dir():
         ROOT_DIR + "/packages/fetchai/connections/stub",
         Identity("name", "address"),
         CryptoStore(),
+        MagicMock(),
     )
 
 
