@@ -16,11 +16,13 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
+
 """This module contains the tests for the dialogue/base.py module."""
+import re
 import sys
 from typing import FrozenSet, Tuple, Type, cast
 from unittest import mock
-from unittest.mock import Mock
+from unittest.mock import Mock, patch
 
 import pytest
 
@@ -263,7 +265,7 @@ class TestDialogueBase:
 
         cls.valid_message_2_by_other = DefaultMessage(
             dialogue_reference=(str(1), str(1)),
-            message_id=2,
+            message_id=-1,
             target=1,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello back",
@@ -273,8 +275,8 @@ class TestDialogueBase:
 
         cls.valid_message_3_by_self = DefaultMessage(
             dialogue_reference=(str(1), str(1)),
-            message_id=3,
-            target=2,
+            message_id=2,
+            target=-1,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello back 2",
         )
@@ -352,22 +354,22 @@ class TestDialogueBase:
     def test_try_get_message(self):
         """Test the 'try_get_message' method."""
         assert (
-            self.dialogue._try_get_message(self.valid_message_1_by_self.message_id)
+            self.dialogue.get_message_by_id(self.valid_message_1_by_self.message_id)
             is None
         )
         self.dialogue._update(self.valid_message_1_by_self)
         assert (
-            self.dialogue._try_get_message(self.valid_message_1_by_self.message_id)
+            self.dialogue.get_message_by_id(self.valid_message_1_by_self.message_id)
             == self.valid_message_1_by_self
         )
 
         assert (
-            self.dialogue._try_get_message(self.valid_message_2_by_other.message_id)
+            self.dialogue.get_message_by_id(self.valid_message_2_by_other.message_id)
             is None
         )
         self.dialogue._update(self.valid_message_2_by_other)
         assert (
-            self.dialogue._try_get_message(self.valid_message_2_by_other.message_id)
+            self.dialogue.get_message_by_id(self.valid_message_2_by_other.message_id)
             == self.valid_message_2_by_other
         )
 
@@ -450,7 +452,7 @@ class TestDialogueBase:
         """Negative test for the 'update' method: input message is invalid with respect to the dialogue."""
         invalid_message_1_by_self = DefaultMessage(
             dialogue_reference=(str(1), ""),
-            message_id=2,
+            message_id=200,
             target=1,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello",
@@ -458,13 +460,11 @@ class TestDialogueBase:
         invalid_message_1_by_self.sender = self.agent_address
         invalid_message_1_by_self.to = self.opponent_address
 
-        with pytest.raises(InvalidDialogueMessage) as cm:
+        with pytest.raises(
+            InvalidDialogueMessage,
+            match=r"Message .* is invalid with respect to this dialogue. Error: Invalid message_id. Expected .*. Found 200.",
+        ):
             self.dialogue._update(invalid_message_1_by_self)
-        assert (
-            str(cm.value)
-            == "Message 2 is invalid with respect to this dialogue. Error: "
-            + "Invalid message_id. Expected 1. Found 2."
-        )
 
         assert self.dialogue.last_outgoing_message is None
 
@@ -596,8 +596,8 @@ class TestDialogueBase:
 
         invalid_message_3_by_self = DefaultMessage(
             dialogue_reference=(str(1), str(1)),
-            message_id=3,
-            target=1,
+            message_id=2,
+            target=3,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello back 2",
         )
@@ -606,7 +606,7 @@ class TestDialogueBase:
 
         result, msg = self.dialogue._validate_next_message(invalid_message_3_by_self)
         assert result is False
-        assert msg == "Invalid target. Expected 2. Found 1."
+        assert "Invalid target" in msg
 
     def test_is_valid_next_message_negative_is_valid_fails(self):
         """Negative test for the 'validate_next_message' method: is_valid method fails"""
@@ -644,17 +644,19 @@ class TestDialogueBase:
         invalid_message_1_by_self.sender = self.agent_address
         invalid_message_1_by_self.to = self.opponent_address
 
+        assert self.dialogue.is_empty
         result, msg = self.dialogue._basic_validation(invalid_message_1_by_self)
         assert result is False
         assert msg == "Invalid message_id. Expected 1. Found 2."
 
-    def test_basic_validation_negative_non_initial_message_invalid(self):
+    @patch.object(BaseDialogue, "_validate_message_id", return_value=None)
+    def test_basic_validation_negative_non_initial_message_invalid(self, *mocks):
         """Negative test for the '_basic_validation' method: non-initial message is invalid."""
         self.dialogue._update(self.valid_message_1_by_self)
 
         invalid_message_2_by_other = DefaultMessage(
             dialogue_reference=(str(1), str(1)),
-            message_id=2,
+            message_id=-1,
             target=0,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello back",
@@ -664,10 +666,7 @@ class TestDialogueBase:
 
         result, msg = self.dialogue._basic_validation(invalid_message_2_by_other)
         assert result is False
-        assert (
-            msg
-            == "Invalid target. Expected a value greater than or equal to 1. Found 0."
-        )
+        assert msg == "Invalid target. Expected a non-zero integer. Found 0."
 
     def test_basic_validation_initial_message_positive(self):
         """Positive test for the '_basic_validation_initial_message' method."""
@@ -697,7 +696,7 @@ class TestDialogueBase:
         """Negative test for the '_basic_validation' method: input message has invalid message id."""
         invalid_message_1_by_self = DefaultMessage(
             dialogue_reference=(str(1), ""),
-            message_id=2,
+            message_id=200,
             target=1,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello",
@@ -709,7 +708,7 @@ class TestDialogueBase:
             invalid_message_1_by_self
         )
         assert result is False
-        assert msg == "Invalid message_id. Expected 1. Found 2."
+        assert re.match("Invalid message_id. Expected .*. Found 200.", msg)
 
     def test_basic_validation_initial_message_negative_invalid_target(self):
         """Negative test for the '_basic_validation_initial_message' method: input message has invalid target."""
@@ -790,7 +789,7 @@ class TestDialogueBase:
 
         invalid_message_2_by_other = DefaultMessage(
             dialogue_reference=(str(1), str(1)),
-            message_id=3,
+            message_id=1000500000,
             target=1,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello back",
@@ -802,9 +801,12 @@ class TestDialogueBase:
             invalid_message_2_by_other
         )
         assert result is False
-        assert msg == "Invalid message_id. Expected 2. Found 3."
+        assert re.match("Invalid message_id. Expected .*. Found 1000500000", msg)
 
-    def test_basic_validation_non_initial_message_negative_invalid_target_1(self):
+    @patch.object(BaseDialogue, "_validate_message_id", return_value=None)
+    def test_basic_validation_non_initial_message_negative_invalid_target_1(
+        self, *mocks
+    ):
         """Negative test for the '_basic_validation_non_initial_message' method: input message has target less than 1."""
         self.dialogue._update(self.valid_message_1_by_self)
 
@@ -822,10 +824,7 @@ class TestDialogueBase:
             invalid_message_2_by_other
         )
         assert result is False
-        assert (
-            msg
-            == "Invalid target. Expected a value greater than or equal to 1. Found 0."
-        )
+        assert msg == "Invalid target. Expected a non-zero integer. Found 0."
 
     def test_basic_validation_non_initial_message_negative_invalid_target_2(self):
         """Negative test for the '_basic_validation_non_initial_message' method: input message has target greater than the id of the last existing message."""
@@ -833,7 +832,7 @@ class TestDialogueBase:
 
         invalid_message_2_by_other = DefaultMessage(
             dialogue_reference=(str(1), str(1)),
-            message_id=2,
+            message_id=-1,
             target=2,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello back",
@@ -845,17 +844,18 @@ class TestDialogueBase:
             invalid_message_2_by_other
         )
         assert result is False
-        assert (
-            msg == "Invalid target. Expected a value less than or equal to 1. Found 2."
-        )
+        assert "Invalid target. Expected a value less than " in msg
 
-    def test_basic_validation_non_initial_message_negative_invalid_performative(self):
+    @patch.object(BaseDialogue, "_validate_message_id", return_value=None)
+    def test_basic_validation_non_initial_message_negative_invalid_performative(
+        self, *mocks
+    ):
         """Negative test for the '_basic_validation_non_initial_message' method: input message has invalid performative."""
         self.dialogue._update(self.valid_message_1_by_self)
 
         invalid_message_2_by_other = StateUpdateMessage(
             dialogue_reference=(str(1), str(1)),
-            message_id=2,
+            message_id=Mock(),
             target=1,
             performative=StateUpdateMessage.Performative.APPLY,
             amount_by_currency_id={},
@@ -875,38 +875,6 @@ class TestDialogueBase:
             invalid_message_2_by_other.performative,
         )
 
-    def test_additional_validation_positive(self):
-        """Positive test for the '_additional_rules' method."""
-        result, msg = self.dialogue._additional_validation(self.valid_message_1_by_self)
-        assert result is True
-        assert msg == "The message passes additional validation."
-
-        self.dialogue._update(self.valid_message_1_by_self)
-        self.dialogue._update(self.valid_message_2_by_other)
-
-        result, msg = self.dialogue._additional_validation(self.valid_message_3_by_self)
-        assert result is True
-        assert msg == "The message passes additional validation."
-
-    def test_additional_validation_negative_invalid_target(self):
-        """Negative test for the '_additional_rules' method: input message has invalid target (its target is not the last message of the dialogue)."""
-        self.dialogue._update(self.valid_message_1_by_self)
-        self.dialogue._update(self.valid_message_2_by_other)
-
-        invalid_message_3_by_self = DefaultMessage(
-            dialogue_reference=(str(1), str(1)),
-            message_id=3,
-            target=1,
-            performative=DefaultMessage.Performative.BYTES,
-            content=b"Hello back 2",
-        )
-        invalid_message_3_by_self.sender = self.agent_address
-        invalid_message_3_by_self.to = self.opponent_address
-
-        result, msg = self.dialogue._additional_validation(invalid_message_3_by_self)
-        assert result is False
-        assert msg == "Invalid target. Expected 2. Found 1."
-
     def test_update_dialogue_label_positive(self):
         """Positive test for the 'update_dialogue_label' method."""
         self.dialogue._update(self.valid_message_1_by_self)
@@ -950,16 +918,6 @@ class TestDialogueBase:
         assert str(cm.value) == "Dialogue label cannot be updated."
         assert self.dialogue.dialogue_label != new_label
 
-    def test_interleave(self):
-        """Test the '_interleave' method."""
-        list_1 = [1, 3, 5, 7]
-        list_2 = [2, 4, 6, 8]
-        assert Dialogue._interleave(list_1, list_2) == [1, 2, 3, 4, 5, 6, 7, 8]
-
-        list_3 = [1, 3, 4]
-        list_4 = [2]
-        assert Dialogue._interleave(list_3, list_4) == [1, 2, 3, 4]
-
     def test___str__1(self):
         """Test the '__str__' method: dialogue is self initiated"""
         self.dialogue._update(self.valid_message_1_by_self)
@@ -967,9 +925,7 @@ class TestDialogueBase:
 
         self.dialogue._update(self.valid_message_3_by_self)
 
-        dialogue_str = (
-            "Dialogue Label: 1__agent 2_agent 1\nbytes( )\nbytes( )\nbytes( )"
-        )
+        dialogue_str = "Dialogue Label:\n1__agent 2_agent 1\nMessages:\nmessage_id=1, target=0, performative=bytes\nmessage_id=-1, target=1, performative=bytes\nmessage_id=2, target=-1, performative=bytes\n"
 
         assert str(self.dialogue) == dialogue_str
 
@@ -987,7 +943,7 @@ class TestDialogueBase:
 
         valid_message_2_by_self = DefaultMessage(
             dialogue_reference=(str(1), str(1)),
-            message_id=2,
+            message_id=-1,
             target=1,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello back",
@@ -999,8 +955,8 @@ class TestDialogueBase:
 
         valid_message_3_by_other = DefaultMessage(
             dialogue_reference=(str(1), str(1)),
-            message_id=3,
-            target=2,
+            message_id=2,
+            target=-1,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello back 2",
         )
@@ -1009,9 +965,7 @@ class TestDialogueBase:
 
         self.dialogue_opponent_started._update(valid_message_3_by_other)
 
-        dialogue_str = (
-            "Dialogue Label: 1_1_agent 2_agent 2\nbytes( )\nbytes( )\nbytes( )"
-        )
+        dialogue_str = "Dialogue Label:\n1_1_agent 2_agent 2\nMessages:\nmessage_id=1, target=0, performative=bytes\nmessage_id=-1, target=1, performative=bytes\nmessage_id=2, target=-1, performative=bytes\n"
 
         assert str(self.dialogue_opponent_started) == dialogue_str
 
@@ -1183,16 +1137,14 @@ class TestDialoguesBase:
         assert (
             len(self.own_dialogues._dialogues_storage._dialogues_by_dialogue_label) == 0
         )
-        with pytest.raises(SyntaxError) as cm:
+        with pytest.raises(
+            ValueError, match="Invalid initial performative. Expected one of"
+        ):
             self.own_dialogues.create(
                 self.opponent_address,
                 DefaultMessage.Performative.ERROR,
                 content=b"Hello",
             )
-        assert (
-            str(cm.value)
-            == "Cannot create a dialogue with the specified performative and contents."
-        )
         assert (
             len(self.own_dialogues._dialogues_storage._dialogues_by_dialogue_label) == 0
         )
@@ -1235,7 +1187,7 @@ class TestDialoguesBase:
         )
         valid_message_2_by_other = DefaultMessage(
             dialogue_reference=dialogue_reference,
-            message_id=msg.message_id + 1,
+            message_id=dialogue.get_incoming_next_message_id(),
             target=msg.message_id,
             performative=DefaultMessage.Performative.BYTES,
             content=b"Hello back",
@@ -1570,7 +1522,8 @@ class TestDialoguesBase:
         assert retrieved_dialogue is not None
         assert retrieved_dialogue.dialogue_label == dialogue.dialogue_label
 
-    def test_get_dialogue_negative_invalid_reference(self):
+    @patch.object(BaseDialogue, "_validate_message_id", return_value=None)
+    def test_get_dialogue_negative_invalid_reference(self, *mocks):
         """Negative test for the 'get_dialogue' method: the input message has invalid dialogue reference."""
         msg, dialogue = self.own_dialogues.create(
             self.opponent_address, DefaultMessage.Performative.BYTES, content=b"Hello"
@@ -1616,7 +1569,7 @@ class TestDialoguesBase:
             self.opponent_address, DefaultMessage.Performative.BYTES, content=b"Hello"
         )
 
-        retrieved_dialogue = self.own_dialogues._get_dialogue_from_label(
+        retrieved_dialogue = self.own_dialogues.get_dialogue_from_label(
             dialogue.dialogue_label
         )
         assert retrieved_dialogue.dialogue_label == dialogue.dialogue_label
@@ -1631,9 +1584,7 @@ class TestDialoguesBase:
             (str(1), "error"), self.opponent_address, self.agent_address
         )
 
-        retrieved_dialogue = self.own_dialogues._get_dialogue_from_label(
-            incorrect_label
-        )
+        retrieved_dialogue = self.own_dialogues.get_dialogue_from_label(incorrect_label)
         assert retrieved_dialogue is None
 
     def test_create_self_initiated_positive(self):
