@@ -69,11 +69,15 @@ class TestSkillContext:
             {FETCHAI: FETCHAI_PRIVATE_KEY_PATH, ETHEREUM: ETHEREUM_PRIVATE_KEY_PATH}
         )
         cls.connection = _make_dummy_connection()
+        resources = Resources()
+        resources.add_connection(cls.connection)
         cls.identity = Identity(
             "name", addresses=cls.wallet.addresses, default_address_key=FETCHAI,
         )
-        cls.my_aea = AEA(cls.identity, cls.wallet, resources=Resources())
-        cls.my_aea.resources.add_connection(cls.connection)
+        cls.my_aea = AEA(
+            cls.identity, cls.wallet, data_dir=MagicMock(), resources=resources
+        )
+
         cls.skill_context = SkillContext(
             cls.my_aea.context, skill=MagicMock(contracts={})
         )
